--[[
  
   TitaonZoneLevel.lua v1.5
   Author/Modder: Asniper - asniper@rogers.com
   Comments: Based off The Nerd Wonders ZoneLevel, 
             Also Thanks to Ezarras for his collection.
   

   A Real big thanks to BlackTotem for creating the localization information.

-- ]]


local zLevelLow;
local zLevelHigh;

function TitanPanelZoneLevelButton_OnLoad()
	this.registry = { 
		id = "ZoneLevel",
		menuText = TITAN_ZONELEVEL_MENU_TEXT, 
		buttonTextFunction = "TitanPanelZoneLevelButton_GetButtonText", 
		tooltipTitle = TITAN_ZONELEVEL_TOOLTIP,
		tooltipTextFunction = "TitanPanelZoneLevelButton_GetTooltipText", 
	};

	-- Register events
	this:RegisterEvent("MINIMAP_ZONE_CHANGED");
	this:RegisterEvent("ZONE_CHANGED_NEW_AREA");
	this:RegisterEvent("PLAYER_LEVEL_UP");
	this:RegisterEvent("MINIMAP_ZONE_CHANGED");

	-- Construct collections
	zLevelLow={};
	zLevelHigh={};
	ZLevel_MakeTables();
	
	if not (TitanZoneLevelSettings) then TitanZoneLevelSettings = {}; end
end
function TitanPanelGetZone()
	local zone = GetSubZoneText();
	if(zLevelLow[zone] == nil) then
		zone = GetRealZoneText();
	end
	if(zLevelLow[zone] == nil) then
		zone = TITAN_ZONELEVEL_LOADING;
	end
	return zone;
end

function TitanPanelZoneLevelButton_GetButtonText(id)
	this.pvpType = GetZonePVPInfo();
	local id = TitanUtils_GetButton(id, true);
	local zone = TitanPanelGetZone()
	local miniZone = GetMinimapZoneText();

	local zoneText = TitanPanelZoneLevelSetText(zLevelLow[zone].."-"..zLevelHigh[zone]);
	
	if(TitanZoneLevelSettings.ShowZoneName and zLevelLow[zone] > 1) then
		if(this.pvpType=="hostile") then
			zoneText = format(TitanUtils_GetRedText(miniZone)..TitanUtils_GetNormalText(" (")..zoneText..TitanUtils_GetNormalText(")"));
		elseif(this.pvpType =="contested") then
			zoneText = format(TitanUtils_GetNormalText(miniZone)..TitanUtils_GetNormalText(" (")..zoneText..TitanUtils_GetNormalText(")"));
		else
	
			zoneText = format(TitanUtils_GetHighlightText(miniZone)..TitanUtils_GetNormalText(" (")..zoneText..TitanUtils_GetNormalText(")"));
		end
	else
		zoneText = zoneText
	end
	if not(TitanZoneLevelSettings.ShowName) then
		zoneText = format(TITAN_ZONELEVEL_BUTTON_TEXT,zoneText);
	end
	return zoneText;
end


function TitanPanelZoneLevelButton_GetTooltipText()
	local zone= TitanPanelGetZone();
	local txt= TitanUtils_GetNormalText("Zone: ")..TitanUtils_GetHighlightText(GetMinimapZoneText());
	this.pvpType = GetZonePVPInfo();

	if(zLevelLow[zone] < 1)	then
		txt = txt.."\n"..ZONELEVEL_ZONETEXT..TitanUtils_GetHighlightText("n\\a".."\n");
	else
		txt = txt.."\n"..ZONELEVEL_ZONETEXT..TitanPanelZoneLevelSetText(zLevelLow[zone].."-"..zLevelHigh[zone]).."\n";
	end

	txt=txt..TitanUtils_GetNormalText(TITAN_ZONELEVEL_PVP)
	if (this.pvpType == TITAN_ZONELEVEL_HOSTILE) then -- Enemy or PvP
		txt = txt..TitanUtils_GetRedText(TITAN_ZONELEVEL_HOSTILE);
	elseif (this.pvpType == TITAN_ZONELEVEL_FRIENDLY) then -- Friendly
		txt = txt..TitanUtils_GetGreenText(TITAN_ZONELEVEL_FRIENDLY);
	elseif (this.pvpType == TITAN_ZONELEVEL_CONTESTED) then
		txt = txt..TitanUtils_GetNormalText(TITAN_ZONELEVEL_CONTESTED);
	else
		txt = TitanUtils_GetHighlightText("n\\a");
	end
	
	return txt;
end

function TitanPanelZoneLevelSetText(text)
	local zone = TitanPanelGetZone();
	local level = UnitLevel("player");
	local low = zLevelLow[zone];
	local high = zLevelHigh[zone];

	if(zLevelLow[zone]) then
		local mid = (low+high)/2;

		if(zLevelLow[zone] < 1)then -- Display town zone name when possible
			text =  TitanUtils_GetHighlightText(zone);
		elseif(high < level-5) then -- Grey Text - Didn't know how to use the colour function supplied :(
			text = "|cff999999"..text;
		elseif(low > level+5) then -- Red Text
			text = TitanUtils_GetRedText(text);
		elseif(mid < level) then -- Green Text 
			text = TitanUtils_GetGreenText(text);
		else -- Yellow Text
			text = TitanUtils_GetNormalText(text);
		end
	else
		text = ZONELEVEL_ZONENOTFOUNDTOOLTIP;
	end
	return text
end



function TitanPanelRightClickMenu_PrepareZoneLevelMenu()
	local id = "ZoneLevel";
	local info;
	
	TitanPanelRightClickMenu_AddTitle(TitanPlugins[id].menuText);
	info = {};
	info.text = TITAN_ZONELEVEL_MENU_SHOW_ZONE_NAME;
	info.func = TitanPanelZoneLevelButton_ShowZoneName;
	info.checked = TitanZoneLevelSettings.ShowZoneName;
	UIDropDownMenu_AddButton(info);

	info.text = TITAN_ZONELEVEL_MENU_SHOW_NAME;
	info.func = TitanPanelZoneLevelButton_ShowName;
	info.checked = TitanZoneLevelSettings.ShowName;
	UIDropDownMenu_AddButton(info);

	TitanPanelRightClickMenu_AddSpacer();	

	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_CUSTOMIZE..TITAN_PANEL_MENU_POPUP_IND, id, TITAN_PANEL_MENU_FUNC_CUSTOMIZE);
	TitanPanelRightClickMenu_AddCommand(TITAN_PANEL_MENU_HIDE, id, TITAN_PANEL_MENU_FUNC_HIDE);
end

function TitanPanelZoneLevelButton_ShowZoneName()
	TitanZoneLevelSettings.ShowZoneName = TitanUtils_Toggle(TitanZoneLevelSettings.ShowZoneName);
	TitanPanelButton_UpdateButton("ZoneLevel");
end
function TitanPanelZoneLevelButton_ShowName()
	TitanZoneLevelSettings.ShowName = TitanUtils_Toggle(TitanZoneLevelSettings.ShowName);
	TitanPanelButton_UpdateButton("ZoneLevel");
end

-- Update Button Text on Events: MINIMAP_ZONE_CHANGED, ZONE_CHANGED_NEW_AREA and PLAYER_LEVEL_UP.
function TitanPanelZoneLevelButton_OnEvent()
	TitanPanelButton_UpdateButton("ZoneLevel");
	TitanPanelButton_UpdateTooltip()
end

-- Collection for each zone
function ZLevel_MakeTables()

--<< A >>--
    zLevelHigh[TITAN_ZONELEVEL_ABAS]=54;
    zLevelLow[TITAN_ZONELEVEL_ABAS]=41;
    zLevelHigh[TITAN_ZONELEVEL_ADST]=26;
    zLevelLow[TITAN_ZONELEVEL_ADST]=19;
    zLevelHigh[TITAN_ZONELEVEL_AEPE]=41;
    zLevelLow[TITAN_ZONELEVEL_AEPE]=41;
    zLevelHigh[TITAN_ZONELEVEL_AGGO]=22;
    zLevelLow[TITAN_ZONELEVEL_AGGO]=13;
    zLevelHigh[TITAN_ZONELEVEL_AGFACR]=13;
    zLevelLow[TITAN_ZONELEVEL_AGFACR]=9;
    zLevelHigh[TITAN_ZONELEVEL_AGMI]=11;
    zLevelLow[TITAN_ZONELEVEL_AGMI]=6;
    zLevelHigh[TITAN_ZONELEVEL_AGEN]=43;
    zLevelLow[TITAN_ZONELEVEL_AGEN]=37;
    zLevelHigh[TITAN_ZONELEVEL_AGFO]=39;
    zLevelLow[TITAN_ZONELEVEL_AGFO]=35;
    zLevelHigh[TITAN_ZONELEVEL_AGWA]=48;
    zLevelLow[TITAN_ZONELEVEL_AGWA]=43;
    zLevelHigh[TITAN_ZONELEVEL_ALFA]=19;
    zLevelLow[TITAN_ZONELEVEL_ALFA]=11;
    zLevelHigh[TITAN_ZONELEVEL_ALST]=12;
    zLevelLow[TITAN_ZONELEVEL_ALST]=10;
    zLevelHigh[TITAN_ZONELEVEL_ALOFST]=57;
    zLevelLow[TITAN_ZONELEVEL_ALOFST]=53;
    zLevelHigh[TITAN_ZONELEVEL_ALMO]=37;
    zLevelLow[TITAN_ZONELEVEL_ALMO]=21;
    zLevelHigh[TITAN_ZONELEVEL_ALVA]=50;
    zLevelLow[TITAN_ZONELEVEL_ALVA]=30;
    zLevelHigh[TITAN_ZONELEVEL_ALMI]=21;
    zLevelLow[TITAN_ZONELEVEL_ALMI]=16;
    zLevelHigh[TITAN_ZONELEVEL_AM]=21;
    zLevelLow[TITAN_ZONELEVEL_AM]=12;
    zLevelHigh[TITAN_ZONELEVEL_AMRA]=12;
    zLevelLow[TITAN_ZONELEVEL_AMRA]=6;
    zLevelHigh[TITAN_ZONELEVEL_AMAR]=16;
    zLevelLow[TITAN_ZONELEVEL_AMAR]=10;
    zLevelHigh[TITAN_ZONELEVEL_ANEN]=32;
    zLevelLow[TITAN_ZONELEVEL_ANEN]=24;
    zLevelHigh[TITAN_ZONELEVEL_ANFO]=39;
    zLevelLow[TITAN_ZONELEVEL_ANFO]=35;
    zLevelHigh[TITAN_ZONELEVEL_APRE]=41;
    zLevelLow[TITAN_ZONELEVEL_APRE]=39;
    zLevelHigh[TITAN_ZONELEVEL_ARHI]=50;
    zLevelLow[TITAN_ZONELEVEL_ARHI]=30;
    zLevelHigh[TITAN_ZONELEVEL_ASH]=40;
    zLevelLow[TITAN_ZONELEVEL_ASH]=18;
    zLevelHigh[TITAN_ZONELEVEL_AST]=37;
    zLevelLow[TITAN_ZONELEVEL_AST]=19;
    zLevelHigh[TITAN_ZONELEVEL_AU]=0;
    zLevelLow[TITAN_ZONELEVEL_AU]=0;
    zLevelHigh[TITAN_ZONELEVEL_AZ]=55;
    zLevelLow[TITAN_ZONELEVEL_AZ]=44;
    zLevelHigh[TITAN_ZONELEVEL_AZMI]=30;
    zLevelLow[TITAN_ZONELEVEL_AZMI]=24;
--<< B >>--
    zLevelHigh[TITAN_ZONELEVEL_BA]=55;
    zLevelLow[TITAN_ZONELEVEL_BA]=35;
    zLevelHigh[TITAN_ZONELEVEL_BAMO]=30;
    zLevelLow[TITAN_ZONELEVEL_BAMO]=22;
    zLevelHigh[TITAN_ZONELEVEL_BAKE]=30;
    zLevelLow[TITAN_ZONELEVEL_BAKE]=23;
    zLevelHigh[TITAN_ZONELEVEL_BADU]=9;
    zLevelLow[TITAN_ZONELEVEL_BADU]=7;
    zLevelHigh[TITAN_ZONELEVEL_BALARU]=55;
    zLevelLow[TITAN_ZONELEVEL_BALARU]=32;
    zLevelHigh[TITAN_ZONELEVEL_BAMARU]=42;
    zLevelLow[TITAN_ZONELEVEL_BAMARU]=37;
    zLevelHigh[TITAN_ZONELEVEL_BAFA]=11;
    zLevelLow[TITAN_ZONELEVEL_BAFA]=7;
    zLevelHigh[TITAN_ZONELEVEL_BAR]=22;
    zLevelLow[TITAN_ZONELEVEL_BAR]=20;
    zLevelHigh[TITAN_ZONELEVEL_BAR]=52;
    zLevelLow[TITAN_ZONELEVEL_BAR]=50;
    zLevelHigh[TITAN_ZONELEVEL_BAAR]=17;
    zLevelLow[TITAN_ZONELEVEL_BAAR]=10;
    zLevelHigh[TITAN_ZONELEVEL_BAHA]=20;
    zLevelLow[TITAN_ZONELEVEL_BAHA]=19;
    zLevelHigh[TITAN_ZONELEVEL_BAST]=60;
    zLevelLow[TITAN_ZONELEVEL_BAST]=52;
    zLevelHigh[TITAN_ZONELEVEL_BEHE]=53;
    zLevelLow[TITAN_ZONELEVEL_BEHE]=46;
    zLevelHigh[TITAN_ZONELEVEL_BEHA]=0;
    zLevelLow[TITAN_ZONELEVEL_BEHA]=0;
    zLevelHigh[TITAN_ZONELEVEL_BEPE]=21;
    zLevelLow[TITAN_ZONELEVEL_BEPE]=19;
    zLevelHigh[TITAN_ZONELEVEL_BIRE]=55;
    zLevelLow[TITAN_ZONELEVEL_BIRE]=52;
    zLevelHigh[TITAN_ZONELEVEL_BLCHMA]=25;
    zLevelLow[TITAN_ZONELEVEL_BLCHMA]=20;
    zLevelHigh[TITAN_ZONELEVEL_BLDE]=27;
    zLevelLow[TITAN_ZONELEVEL_BLDE]=20;
    zLevelHigh[TITAN_ZONELEVEL_BLE]=30;
    zLevelLow[TITAN_ZONELEVEL_BLE]=18;
    zLevelHigh[TITAN_ZONELEVEL_BLDE]=56
    zLevelLow[TITAN_ZONELEVEL_BLDE]=48
    zLevelHigh[TITAN_ZONELEVEL_BLMO]=58;
    zLevelLow[TITAN_ZONELEVEL_BLMO]=46;
    zLevelHigh[TITAN_ZONELEVEL_BLPA]=53;
    zLevelLow[TITAN_ZONELEVEL_BLPA]=51;
    zLevelHigh[TITAN_ZONELEVEL_BLSP]=55;
    zLevelLow[TITAN_ZONELEVEL_BLSP]=53;
    zLevelHigh[TITAN_ZONELEVEL_BLST]=58;
    zLevelLow[TITAN_ZONELEVEL_BLST]=54;
    zLevelHigh[TITAN_ZONELEVEL_BLRI]=26;
    zLevelLow[TITAN_ZONELEVEL_BLRI]=20;
    zLevelHigh[TITAN_ZONELEVEL_BLCO]=0;
    zLevelLow[TITAN_ZONELEVEL_BLCO]=0;
    zLevelHigh[TITAN_ZONELEVEL_BLSH]=0;
    zLevelLow[TITAN_ZONELEVEL_BLSH]=0;
    zLevelHigh[TITAN_ZONELEVEL_BLRI]=25;
    zLevelLow[TITAN_ZONELEVEL_BLRI]=18;
    zLevelHigh[TITAN_ZONELEVEL_BLLA]=58;
    zLevelLow[TITAN_ZONELEVEL_BLLA]=54;
    zLevelHigh[TITAN_ZONELEVEL_BLA]=20;
    zLevelLow[TITAN_ZONELEVEL_BLA]=16;
    zLevelHigh[TITAN_ZONELEVEL_BLBA]=10;
    zLevelLow[TITAN_ZONELEVEL_BLBA]=5;
    zLevelHigh[TITAN_ZONELEVEL_BLLAN]=57;
    zLevelLow[TITAN_ZONELEVEL_BLLAN]=45;
    zLevelHigh[TITAN_ZONELEVEL_BLVI]=14;
    zLevelLow[TITAN_ZONELEVEL_BLVI]=5;
    zLevelHigh[TITAN_ZONELEVEL_BLCO]=43;
    zLevelLow[TITAN_ZONELEVEL_BLCO]=40;
    zLevelHigh[TITAN_ZONELEVEL_BLFA]=56;
    zLevelLow[TITAN_ZONELEVEL_BLFA]=49;
    zLevelHigh[TITAN_ZONELEVEL_BLPO]=62;
    zLevelLow[TITAN_ZONELEVEL_BLPO]=55;
    zLevelHigh[TITAN_ZONELEVEL_BLRIV]=62;
    zLevelLow[TITAN_ZONELEVEL_BLRIV]=49;
    zLevelHigh[TITAN_ZONELEVEL_BLU]=37;
    zLevelLow[TITAN_ZONELEVEL_BLU]=35;
    zLevelHigh[TITAN_ZONELEVEL_BLMA]=25;
    zLevelLow[TITAN_ZONELEVEL_BLMA]=20;
    zLevelHigh[TITAN_ZONELEVEL_BOLE]=45;
    zLevelLow[TITAN_ZONELEVEL_BOLE]=42;
    zLevelHigh[TITAN_ZONELEVEL_BOHO]=37;
    zLevelLow[TITAN_ZONELEVEL_BOHO]=33;
    zLevelHigh[TITAN_ZONELEVEL_BOBA]=60;
    zLevelLow[TITAN_ZONELEVEL_BOBA]=30;
    zLevelHigh[TITAN_ZONELEVEL_BOSH]=62;
    zLevelLow[TITAN_ZONELEVEL_BOSH]=61;
    zLevelHigh[TITAN_ZONELEVEL_BOLOADMI]=0;
    zLevelLow[TITAN_ZONELEVEL_BOLOADMI]=0;
    zLevelHigh[TITAN_ZONELEVEL_BOLODEMI]=19;
    zLevelLow[TITAN_ZONELEVEL_BOLODEMI]=14;
    zLevelHigh[TITAN_ZONELEVEL_BOGO]=50;
    zLevelLow[TITAN_ZONELEVEL_BOGO]=30;
    zLevelHigh[TITAN_ZONELEVEL_BOHA]=39;
    zLevelLow[TITAN_ZONELEVEL_BOHA]=35;
    zLevelHigh[TITAN_ZONELEVEL_BOOU]=36;
    zLevelLow[TITAN_ZONELEVEL_BOOU]=33;
    zLevelHigh[TITAN_ZONELEVEL_BORA]=20;
    zLevelLow[TITAN_ZONELEVEL_BORA]=16;
    zLevelHigh[TITAN_ZONELEVEL_BRAVI]=55;
    zLevelLow[TITAN_ZONELEVEL_BRAVI]=36;
    zLevelHigh[TITAN_ZONELEVEL_BRPUPA]=10;
    zLevelLow[TITAN_ZONELEVEL_BRPUPA]=7;
    zLevelHigh[TITAN_ZONELEVEL_BRA]=26;
    zLevelLow[TITAN_ZONELEVEL_BRA]=16;
    zLevelHigh[TITAN_ZONELEVEL_BRWIME]=0;
    zLevelLow[TITAN_ZONELEVEL_BRWIME]=0;
    zLevelHigh[TITAN_ZONELEVEL_BREVI]=8;
    zLevelLow[TITAN_ZONELEVEL_BREVI]=7;
    zLevelHigh[TITAN_ZONELEVEL_BRLA]=16;
    zLevelLow[TITAN_ZONELEVEL_BRLA]=6;
    zLevelHigh[TITAN_ZONELEVEL_BRGR]=29;
    zLevelLow[TITAN_ZONELEVEL_BRGR]=20;
    zLevelHigh[TITAN_ZONELEVEL_BRI]=7;
    zLevelLow[TITAN_ZONELEVEL_BRI]=5;
    zLevelHigh[TITAN_ZONELEVEL_BRPI]=48;
    zLevelLow[TITAN_ZONELEVEL_BRPI]=43;
    zLevelHigh[TITAN_ZONELEVEL_BRMI]=60;
    zLevelLow[TITAN_ZONELEVEL_BRMI]=55;
    zLevelHigh[TITAN_ZONELEVEL_BUFA]=0;
    zLevelLow[TITAN_ZONELEVEL_BUFA]=0;
    zLevelHigh[TITAN_ZONELEVEL_BUBLCO]=5;
    zLevelLow[TITAN_ZONELEVEL_BUBLCO]=3;
    zLevelHigh[TITAN_ZONELEVEL_BUST]=58;
    zLevelLow[TITAN_ZONELEVEL_BUST]=50;
--<< C >>--
    zLevelHigh[TITAN_ZONELEVEL_CA]=0;
    zLevelLow[TITAN_ZONELEVEL_CA]=0;
    zLevelHigh[TITAN_ZONELEVEL_CAAP]=17;
    zLevelLow[TITAN_ZONELEVEL_CAAP]=14;
    zLevelHigh[TITAN_ZONELEVEL_CABO]=43;
    zLevelLow[TITAN_ZONELEVEL_CABO]=36;
    zLevelHigh[TITAN_ZONELEVEL_CACA]=45;
    zLevelLow[TITAN_ZONELEVEL_CACA]=36;
    zLevelHigh[TITAN_ZONELEVEL_CAET]=30;
    zLevelLow[TITAN_ZONELEVEL_CAET]=26;
    zLevelHigh[TITAN_ZONELEVEL_CAKO]=35;
    zLevelLow[TITAN_ZONELEVEL_CAKO]=35;
    zLevelHigh[TITAN_ZONELEVEL_CAMO]=65;
    zLevelLow[TITAN_ZONELEVEL_CAMO]=30;
    zLevelHigh[TITAN_ZONELEVEL_CATA]=40;
    zLevelLow[TITAN_ZONELEVEL_CATA]=15;
    zLevelHigh[TITAN_ZONELEVEL_CAWU]=43;
    zLevelLow[TITAN_ZONELEVEL_CAWU]=36;
    zLevelHigh[TITAN_ZONELEVEL_CAOFTI]=50;
    zLevelLow[TITAN_ZONELEVEL_CAOFTI]=50;
    zLevelHigh[TITAN_ZONELEVEL_CHBRVA]=11;
    zLevelLow[TITAN_ZONELEVEL_CHBRVA]=6;
    zLevelHigh[TITAN_ZONELEVEL_CHPO]=58;
    zLevelLow[TITAN_ZONELEVEL_CHPO]=30;
    zLevelHigh[TITAN_ZONELEVEL_CIOFEABI]=42;
    zLevelLow[TITAN_ZONELEVEL_CIOFEABI]=30;
    zLevelHigh[TITAN_ZONELEVEL_CIOFINBI]=42;
    zLevelLow[TITAN_ZONELEVEL_CIOFINBI]=30;
    zLevelHigh[TITAN_ZONELEVEL_CIOFOUBI]=42;
    zLevelLow[TITAN_ZONELEVEL_CIOFOUBI]=30;
    zLevelHigh[TITAN_ZONELEVEL_CIOFWEBI]=39;
    zLevelLow[TITAN_ZONELEVEL_CIOFWEBI]=30;
    zLevelHigh[TITAN_ZONELEVEL_CLFA]=17;
    zLevelLow[TITAN_ZONELEVEL_CLFA]=13;
    zLevelHigh[TITAN_ZONELEVEL_CLRI]=20;
    zLevelLow[TITAN_ZONELEVEL_CLRI]=13;
    zLevelHigh[TITAN_ZONELEVEL_COHEMA]=9;
    zLevelLow[TITAN_ZONELEVEL_COHEMA]=5;
    zLevelHigh[TITAN_ZONELEVEL_COPA]=6;
    zLevelLow[TITAN_ZONELEVEL_COPA]=1;
    zLevelHigh[TITAN_ZONELEVEL_COVA]=5;
    zLevelLow[TITAN_ZONELEVEL_COVA]=1;
    zLevelHigh[TITAN_ZONELEVEL_COCR]=58;
    zLevelLow[TITAN_ZONELEVEL_COCR]=54;
    zLevelHigh[TITAN_ZONELEVEL_COSA]=34;
    zLevelLow[TITAN_ZONELEVEL_COSA]=20;
    zLevelHigh[TITAN_ZONELEVEL_CRLA]=27;
    zLevelLow[TITAN_ZONELEVEL_CRLA]=18;
    zLevelHigh[TITAN_ZONELEVEL_CRGUTO]=55;
    zLevelLow[TITAN_ZONELEVEL_CRGUTO]=53;
    zLevelHigh[TITAN_ZONELEVEL_CROU]=11;
    zLevelLow[TITAN_ZONELEVEL_CROU]=7;
    zLevelHigh[TITAN_ZONELEVEL_CRSOU]=7;
    zLevelLow[TITAN_ZONELEVEL_CRSOU]=6;
    zLevelHigh[TITAN_ZONELEVEL_CRHO]=36;
    zLevelLow[TITAN_ZONELEVEL_CRHO]=35;
    zLevelHigh[TITAN_ZONELEVEL_CRLA]=9;
    zLevelLow[TITAN_ZONELEVEL_CRLA]=5;
    zLevelHigh[TITAN_ZONELEVEL_CRMI]=42;
    zLevelLow[TITAN_ZONELEVEL_CRMI]=41;
--<< D >>--
    zLevelHigh[TITAN_ZONELEVEL_DAFA]=35;
    zLevelLow[TITAN_ZONELEVEL_DAFA]=30;
    zLevelHigh[TITAN_ZONELEVEL_DAL]=35;
    zLevelLow[TITAN_ZONELEVEL_DAL]=24;
    zLevelHigh[TITAN_ZONELEVEL_DATE]=56;
    zLevelLow[TITAN_ZONELEVEL_DATE]=50;
    zLevelHigh[TITAN_ZONELEVEL_DAFO]=40;
    zLevelLow[TITAN_ZONELEVEL_DAFO]=30;
    zLevelHigh[TITAN_ZONELEVEL_DAPO]=61;
    zLevelLow[TITAN_ZONELEVEL_DAPO]=49;
    zLevelHigh[TITAN_ZONELEVEL_DAPI]=34;
    zLevelLow[TITAN_ZONELEVEL_DAPI]=24;
    zLevelHigh[TITAN_ZONELEVEL_DARI]=40;
    zLevelLow[TITAN_ZONELEVEL_DARI]=2;
    zLevelHigh[TITAN_ZONELEVEL_DARO]=26;
    zLevelLow[TITAN_ZONELEVEL_DARO]=9;
    zLevelHigh[TITAN_ZONELEVEL_DAST]=8;
    zLevelLow[TITAN_ZONELEVEL_DAST]=1;
    zLevelHigh[TITAN_ZONELEVEL_DAGO]=60;
    zLevelLow[TITAN_ZONELEVEL_DAGO]=59;
    zLevelHigh[TITAN_ZONELEVEL_DAR]=0;
    zLevelLow[TITAN_ZONELEVEL_DAR]=0;
    zLevelHigh[TITAN_ZONELEVEL_DAHI]=32;
    zLevelLow[TITAN_ZONELEVEL_DAHI]=22;
    zLevelHigh[TITAN_ZONELEVEL_DALA]=60;
    zLevelLow[TITAN_ZONELEVEL_DALA]=12;
    zLevelHigh[TITAN_ZONELEVEL_DARR]=55;
    zLevelLow[TITAN_ZONELEVEL_DARR]=53;
    zLevelHigh[TITAN_ZONELEVEL_DAWOCA]=29;
    zLevelLow[TITAN_ZONELEVEL_DAWOCA]=25;
    zLevelHigh[TITAN_ZONELEVEL_DESH]=8;
    zLevelLow[TITAN_ZONELEVEL_DESH]=2;
    zLevelHigh[TITAN_ZONELEVEL_DECR]=56;
    zLevelLow[TITAN_ZONELEVEL_DECR]=55;
    zLevelHigh[TITAN_ZONELEVEL_DEAD]=20
    zLevelLow[TITAN_ZONELEVEL_DEAD]=15
    zLevelHigh[TITAN_ZONELEVEL_DEPA]=56;
    zLevelLow[TITAN_ZONELEVEL_DEPA]=55;
    zLevelHigh[TITAN_ZONELEVEL_DEVI]=53;
    zLevelLow[TITAN_ZONELEVEL_DEVI]=47;
    zLevelHigh[TITAN_ZONELEVEL_DEAT]=5;
    zLevelLow[TITAN_ZONELEVEL_DEAT]=1;
    zLevelHigh[TITAN_ZONELEVEL_DEELMI]=15;
    zLevelLow[TITAN_ZONELEVEL_DEELMI]=11;
    zLevelHigh[TITAN_ZONELEVEL_DEFACA]=30;
    zLevelLow[TITAN_ZONELEVEL_DEFACA]=29;
    zLevelHigh[TITAN_ZONELEVEL_DEFARI]=0;
    zLevelLow[TITAN_ZONELEVEL_DEFARI]=0;
    zLevelHigh[TITAN_ZONELEVEL_DEST]=0;
    zLevelLow[TITAN_ZONELEVEL_DEST]=0;
    zLevelHigh[TITAN_ZONELEVEL_DEPL]=17;
    zLevelLow[TITAN_ZONELEVEL_DEPL]=14;
    zLevelHigh[TITAN_ZONELEVEL_DES]=40;
    zLevelLow[TITAN_ZONELEVEL_DES]=30;
    zLevelHigh[TITAN_ZONELEVEL_DIMA]=47;
    zLevelLow[TITAN_ZONELEVEL_DIMA]=43;
    zLevelHigh[TITAN_ZONELEVEL_DIHI]=0;
    zLevelLow[TITAN_ZONELEVEL_DIHI]=0;
    zLevelHigh[TITAN_ZONELEVEL_DRDA]=58;
    zLevelLow[TITAN_ZONELEVEL_DRDA]=55;
    zLevelHigh[TITAN_ZONELEVEL_DRGA]=0;
    zLevelLow[TITAN_ZONELEVEL_DRGA]=0;
    zLevelHigh[TITAN_ZONELEVEL_DRHO]=58;
    zLevelLow[TITAN_ZONELEVEL_DRHO]=45;
    zLevelHigh[TITAN_ZONELEVEL_DRPO]=55;
    zLevelLow[TITAN_ZONELEVEL_DRPO]=50;
    zLevelHigh[TITAN_ZONELEVEL_DRRO]=56;
    zLevelLow[TITAN_ZONELEVEL_DRRO]=50;
    zLevelHigh[TITAN_ZONELEVEL_DRPE]=25;
    zLevelLow[TITAN_ZONELEVEL_DRPE]=10;
    zLevelHigh[TITAN_ZONELEVEL_DRE]=15;
    zLevelLow[TITAN_ZONELEVEL_DRE]=10;
    zLevelHigh[TITAN_ZONELEVEL_DRSH]=38;
    zLevelLow[TITAN_ZONELEVEL_DRSH]=35;
    zLevelHigh[TITAN_ZONELEVEL_DRBO]=62;
    zLevelLow[TITAN_ZONELEVEL_DRBO]=62;
    zLevelHigh[TITAN_ZONELEVEL_DRRA]=11;
    zLevelLow[TITAN_ZONELEVEL_DRRA]=5;
    zLevelHigh[TITAN_ZONELEVEL_DRGO]=38;
    zLevelLow[TITAN_ZONELEVEL_DRGO]=35;
    zLevelHigh[TITAN_ZONELEVEL_DUAL]=22;
    zLevelLow[TITAN_ZONELEVEL_DUAL]=11;
    zLevelHigh[TITAN_ZONELEVEL_DUBA]=0;
    zLevelLow[TITAN_ZONELEVEL_DUBA]=0;
    zLevelHigh[TITAN_ZONELEVEL_DUGA]=32;
    zLevelLow[TITAN_ZONELEVEL_DUGA]=24;
    zLevelHigh[TITAN_ZONELEVEL_DUMA]=59;
    zLevelLow[TITAN_ZONELEVEL_DUMA]=56;
    zLevelHigh[TITAN_ZONELEVEL_DUMOD]=34;
    zLevelLow[TITAN_ZONELEVEL_DUMOD]=27;
    zLevelHigh[TITAN_ZONELEVEL_DUMORO]=12;
    zLevelLow[TITAN_ZONELEVEL_DUMORO]=5;
    zLevelHigh[TITAN_ZONELEVEL_DUCO]=50;
    zLevelLow[TITAN_ZONELEVEL_DUCO]=43;
    zLevelHigh[TITAN_ZONELEVEL_DUKE]=40;
    zLevelLow[TITAN_ZONELEVEL_DUKE]=20;
    zLevelHigh[TITAN_ZONELEVEL_DUR]=45;
    zLevelLow[TITAN_ZONELEVEL_DUR]=1;
    zLevelHigh[TITAN_ZONELEVEL_DUS]=40;
    zLevelLow[TITAN_ZONELEVEL_DUS]=18;
    zLevelHigh[TITAN_ZONELEVEL_DUGR]=0;
    zLevelLow[TITAN_ZONELEVEL_DUGR]=0;
    zLevelHigh[TITAN_ZONELEVEL_DUBA]=43;
    zLevelLow[TITAN_ZONELEVEL_DUBA]=35;
    zLevelHigh[TITAN_ZONELEVEL_DUMA]=55;
    zLevelLow[TITAN_ZONELEVEL_DUMA]=22;
    zLevelHigh[TITAN_ZONELEVEL_DUCA]=11;
    zLevelLow[TITAN_ZONELEVEL_DUCA]=8;
    zLevelHigh[TITAN_ZONELEVEL_DUGU]=40;
    zLevelLow[TITAN_ZONELEVEL_DUGU]=35;
--<< E >>--
    zLevelHigh[TITAN_ZONELEVEL_EAPI]=0;
    zLevelLow[TITAN_ZONELEVEL_EAPI]=0;
    zLevelHigh[TITAN_ZONELEVEL_EAPL]=60;
    zLevelLow[TITAN_ZONELEVEL_EAPL]=12;
    zLevelHigh[TITAN_ZONELEVEL_EAST]=32;
    zLevelLow[TITAN_ZONELEVEL_EAST]=26;
    zLevelHigh[TITAN_ZONELEVEL_EARU]=48;
    zLevelLow[TITAN_ZONELEVEL_EARU]=43;
    zLevelHigh[TITAN_ZONELEVEL_EALOCA]=10;
    zLevelLow[TITAN_ZONELEVEL_EALOCA]=8;
    zLevelHigh[TITAN_ZONELEVEL_EAGA]=57;
    zLevelLow[TITAN_ZONELEVEL_EAGA]=56;
    zLevelHigh[TITAN_ZONELEVEL_EATO]=59;
    zLevelLow[TITAN_ZONELEVEL_EATO]=56;
    zLevelHigh[TITAN_ZONELEVEL_ECIS]=10;
    zLevelLow[TITAN_ZONELEVEL_ECIS]=2;
    zLevelHigh[TITAN_ZONELEVEL_ESRIMI]=8;
    zLevelLow[TITAN_ZONELEVEL_ESRIMI]=3;
    zLevelHigh[TITAN_ZONELEVEL_ELFO]=12;
    zLevelLow[TITAN_ZONELEVEL_ELFO]=1;
    zLevelHigh[TITAN_ZONELEVEL_EMSE]=61;
    zLevelLow[TITAN_ZONELEVEL_EMSE]=61;
    zLevelHigh[TITAN_ZONELEVEL_EMSA]=49;
    zLevelLow[TITAN_ZONELEVEL_EMSA]=47;
    zLevelHigh[TITAN_ZONELEVEL_ETRE]=35;
    zLevelLow[TITAN_ZONELEVEL_ETRE]=31;
    zLevelHigh[TITAN_ZONELEVEL_EVE]=60;
    zLevelLow[TITAN_ZONELEVEL_EVE]=30;
--<< F >>--
    zLevelHigh[TITAN_ZONELEVEL_FACO]=40;
    zLevelLow[TITAN_ZONELEVEL_FACO]=39;
    zLevelHigh[TITAN_ZONELEVEL_FARI]=28;
    zLevelLow[TITAN_ZONELEVEL_FARI]=24;
    zLevelHigh[TITAN_ZONELEVEL_FASKLA]=30;
    zLevelLow[TITAN_ZONELEVEL_FASKLA]=19;
    zLevelHigh[TITAN_ZONELEVEL_FASA]=41;
    zLevelLow[TITAN_ZONELEVEL_FASA]=25;
    zLevelHigh[TITAN_ZONELEVEL_FARE]=0;
    zLevelLow[TITAN_ZONELEVEL_FARE]=0;
    zLevelHigh[TITAN_ZONELEVEL_FAWAPO]=14;
    zLevelLow[TITAN_ZONELEVEL_FAWAPO]=4;
    zLevelHigh[TITAN_ZONELEVEL_FAMI]=20;
    zLevelLow[TITAN_ZONELEVEL_FAMI]=5;
    zLevelHigh[TITAN_ZONELEVEL_FEHO]=42;
    zLevelLow[TITAN_ZONELEVEL_FEHO]=41;
    zLevelHigh[TITAN_ZONELEVEL_FEST]=62;
    zLevelLow[TITAN_ZONELEVEL_FEST]=40;
    zLevelHigh[TITAN_ZONELEVEL_FEHI]=30;
    zLevelLow[TITAN_ZONELEVEL_FEHI]=26;
    zLevelHigh[TITAN_ZONELEVEL_FEVI]=56;
    zLevelLow[TITAN_ZONELEVEL_FEVI]=51;
    zLevelHigh[TITAN_ZONELEVEL_FEFI]=54;
    zLevelLow[TITAN_ZONELEVEL_FEFI]=50;
    zLevelHigh[TITAN_ZONELEVEL_FEL]=55;
    zLevelLow[TITAN_ZONELEVEL_FEL]=1;
    zLevelHigh[TITAN_ZONELEVEL_FEIS]=31;
    zLevelLow[TITAN_ZONELEVEL_FEIS]=15;
    zLevelHigh[TITAN_ZONELEVEL_FEKE]=24;
    zLevelLow[TITAN_ZONELEVEL_FEKE]=16;
    zLevelHigh[TITAN_ZONELEVEL_FESCVA]=46;
    zLevelLow[TITAN_ZONELEVEL_FESCVA]=41;
    zLevelHigh[TITAN_ZONELEVEL_FER]=62;
    zLevelLow[TITAN_ZONELEVEL_FER]=30;
    zLevelHigh[TITAN_ZONELEVEL_FIOFGI]=26;
    zLevelLow[TITAN_ZONELEVEL_FIOFGI]=18;
    zLevelHigh[TITAN_ZONELEVEL_FIPLRI]=56;
    zLevelLow[TITAN_ZONELEVEL_FIPLRI]=50;
    zLevelHigh[TITAN_ZONELEVEL_FISCSH]=24;
    zLevelLow[TITAN_ZONELEVEL_FISCSH]=22;
    zLevelHigh[TITAN_ZONELEVEL_FISTME]=0;
    zLevelLow[TITAN_ZONELEVEL_FISTME]=0;
    zLevelHigh[TITAN_ZONELEVEL_FLCR]=57;
    zLevelLow[TITAN_ZONELEVEL_FLCR]=54;
    zLevelHigh[TITAN_ZONELEVEL_FOSO]=62;
    zLevelLow[TITAN_ZONELEVEL_FOSO]=26;
    zLevelHigh[TITAN_ZONELEVEL_FOED]=20;
    zLevelLow[TITAN_ZONELEVEL_FOED]=5;
    zLevelHigh[TITAN_ZONELEVEL_FOTO]=60;
    zLevelLow[TITAN_ZONELEVEL_FOTO]=60;
    zLevelHigh[TITAN_ZONELEVEL_FORI]=47;
    zLevelLow[TITAN_ZONELEVEL_FORI]=46;
    zLevelHigh[TITAN_ZONELEVEL_FORO]=35;
    zLevelLow[TITAN_ZONELEVEL_FORO]=20;
    zLevelHigh[TITAN_ZONELEVEL_FRIS]=14;
    zLevelLow[TITAN_ZONELEVEL_FRIS]=14;
    zLevelHigh[TITAN_ZONELEVEL_FRHI]=47;
    zLevelLow[TITAN_ZONELEVEL_FRHI]=43;
    zLevelHigh[TITAN_ZONELEVEL_FRPO]=55;
    zLevelLow[TITAN_ZONELEVEL_FRPO]=20;
    zLevelHigh[TITAN_ZONELEVEL_FRHOSP]=56;
    zLevelLow[TITAN_ZONELEVEL_FRHOSP]=53;
    zLevelHigh[TITAN_ZONELEVEL_FRHO]=11;
    zLevelLow[TITAN_ZONELEVEL_FRHO]=7;
    zLevelHigh[TITAN_ZONELEVEL_FRRO]=60;
    zLevelLow[TITAN_ZONELEVEL_FRRO]=50;
    zLevelHigh[TITAN_ZONELEVEL_FRGO]=60;
    zLevelLow[TITAN_ZONELEVEL_FRGO]=59;
    zLevelHigh[TITAN_ZONELEVEL_FRKE]=0;
    zLevelLow[TITAN_ZONELEVEL_FRKE]=0;
    zLevelHigh[TITAN_ZONELEVEL_FURO]=55;
    zLevelLow[TITAN_ZONELEVEL_FURO]=50;
    zLevelHigh[TITAN_ZONELEVEL_FUPUFA]=15;
    zLevelLow[TITAN_ZONELEVEL_FUPUFA]=9;
--<< G >>--
    zLevelHigh[TITAN_ZONELEVEL_GAD]=43;
    zLevelLow[TITAN_ZONELEVEL_GAD]=40;
    zLevelHigh[TITAN_ZONELEVEL_GAWI]=58;
    zLevelLow[TITAN_ZONELEVEL_GAWI]=55;
    zLevelHigh[TITAN_ZONELEVEL_GACR]=0;
    zLevelLow[TITAN_ZONELEVEL_GACR]=0;
    zLevelHigh[TITAN_ZONELEVEL_GAHO]=0;
    zLevelLow[TITAN_ZONELEVEL_GAHO]=0;
    zLevelHigh[TITAN_ZONELEVEL_GAVA]=26;
    zLevelLow[TITAN_ZONELEVEL_GAVA]=21;
    zLevelHigh[TITAN_ZONELEVEL_GACO]=36;
    zLevelLow[TITAN_ZONELEVEL_GACO]=33;
    zLevelHigh[TITAN_ZONELEVEL_GAHA]=10;
    zLevelLow[TITAN_ZONELEVEL_GAHA]=6;
    zLevelHigh[TITAN_ZONELEVEL_GAAR]=50;
    zLevelLow[TITAN_ZONELEVEL_GAAR]=46;
    zLevelHigh[TITAN_ZONELEVEL_GAOFIR]=8;
    zLevelLow[TITAN_ZONELEVEL_GAOFIR]=7;
    zLevelHigh[TITAN_ZONELEVEL_GANA]=34;
    zLevelLow[TITAN_ZONELEVEL_GANA]=24;
    zLevelHigh[TITAN_ZONELEVEL_GEVI]=36;
    zLevelLow[TITAN_ZONELEVEL_GEVI]=32;
    zLevelHigh[TITAN_ZONELEVEL_GHWAPO]=50;
    zLevelLow[TITAN_ZONELEVEL_GHWAPO]=35;
    zLevelHigh[TITAN_ZONELEVEL_GIIS]=0;
    zLevelLow[TITAN_ZONELEVEL_GIIS]=0;
    zLevelHigh[TITAN_ZONELEVEL_GNO]=35;
    zLevelLow[TITAN_ZONELEVEL_GNO]=9;
    zLevelHigh[TITAN_ZONELEVEL_GOSKFA]=38;
    zLevelLow[TITAN_ZONELEVEL_GOSKFA]=32;
    zLevelHigh[TITAN_ZONELEVEL_GOBOQU]=10;
    zLevelLow[TITAN_ZONELEVEL_GOBOQU]=7;
    zLevelHigh[TITAN_ZONELEVEL_GOHOSP]=55;
    zLevelLow[TITAN_ZONELEVEL_GOHOSP]=52;
    zLevelHigh[TITAN_ZONELEVEL_GOCOQU]=17;
    zLevelLow[TITAN_ZONELEVEL_GOCOQU]=10;
    zLevelHigh[TITAN_ZONELEVEL_GORO]=26;
    zLevelLow[TITAN_ZONELEVEL_GORO]=10;
    zLevelHigh[TITAN_ZONELEVEL_GOL]=6;
    zLevelLow[TITAN_ZONELEVEL_GOL]=1;
    zLevelHigh[TITAN_ZONELEVEL_GOOU]=43;
    zLevelLow[TITAN_ZONELEVEL_GOOU]=40;
    zLevelHigh[TITAN_ZONELEVEL_GRVA]=17;
    zLevelLow[TITAN_ZONELEVEL_GRVA]=14;
    zLevelHigh[TITAN_ZONELEVEL_GRVI]=35;
    zLevelLow[TITAN_ZONELEVEL_GRVI]=22;
    zLevelHigh[TITAN_ZONELEVEL_GRBA]=0;
    zLevelLow[TITAN_ZONELEVEL_GRBA]=0;
    zLevelHigh[TITAN_ZONELEVEL_GRCO]=44;
    zLevelLow[TITAN_ZONELEVEL_GRCO]=40;
    zLevelHigh[TITAN_ZONELEVEL_GRPO]=22;
    zLevelLow[TITAN_ZONELEVEL_GRPO]=15;
    zLevelHigh[TITAN_ZONELEVEL_GRRI]=20;
    zLevelLow[TITAN_ZONELEVEL_GRRI]=11;
    zLevelHigh[TITAN_ZONELEVEL_GRFA]=16;
    zLevelLow[TITAN_ZONELEVEL_GRFA]=11;
    zLevelHigh[TITAN_ZONELEVEL_GRBACA]=60;
    zLevelLow[TITAN_ZONELEVEL_GRBACA]=33;
    zLevelHigh[TITAN_ZONELEVEL_GRAN]=19;
    zLevelLow[TITAN_ZONELEVEL_GRAN]=15;
    zLevelHigh[TITAN_ZONELEVEL_GRCA]=37;
    zLevelLow[TITAN_ZONELEVEL_GRCA]=32;
    zLevelHigh[TITAN_ZONELEVEL_GUPO]=0;
    zLevelLow[TITAN_ZONELEVEL_GUPO]=0;
    zLevelHigh[TITAN_ZONELEVEL_GURE]=9;
    zLevelLow[TITAN_ZONELEVEL_GURE]=7;
    zLevelHigh[TITAN_ZONELEVEL_GUAR]=44;
    zLevelLow[TITAN_ZONELEVEL_GUAR]=37;
--<< H >>--
    zLevelHigh[TITAN_ZONELEVEL_HAEN]=53;
    zLevelLow[TITAN_ZONELEVEL_HAEN]=44;
    zLevelHigh[TITAN_ZONELEVEL_HAM]=38;
    zLevelLow[TITAN_ZONELEVEL_HAM]=30;
    zLevelHigh[TITAN_ZONELEVEL_HASISI1]=0;
    zLevelLow[TITAN_ZONELEVEL_HASISI1]=0;
    zLevelHigh[TITAN_ZONELEVEL_HASISI2]=39;
    zLevelLow[TITAN_ZONELEVEL_HASISI2]=35;
    zLevelHigh[TITAN_ZONELEVEL_HEA]=61;
    zLevelLow[TITAN_ZONELEVEL_HEA]=55;
    zLevelHigh[TITAN_ZONELEVEL_HEBELA]=12;
    zLevelLow[TITAN_ZONELEVEL_HEBELA]=7;
    zLevelHigh[TITAN_ZONELEVEL_HECL]=55;
    zLevelLow[TITAN_ZONELEVEL_HECL]=53;
    zLevelHigh[TITAN_ZONELEVEL_HIPA]=0;
    zLevelLow[TITAN_ZONELEVEL_HIPA]=0;
    zLevelHigh[TITAN_ZONELEVEL_HIPE]=31;
    zLevelLow[TITAN_ZONELEVEL_HIPE]=28;
    zLevelHigh[TITAN_ZONELEVEL_HIWI]=46;
    zLevelLow[TITAN_ZONELEVEL_HIWI]=41;
    zLevelHigh[TITAN_ZONELEVEL_HIG]=32;
    zLevelLow[TITAN_ZONELEVEL_HIG]=27;
    zLevelHigh[TITAN_ZONELEVEL_HIFI]=33;
    zLevelLow[TITAN_ZONELEVEL_HIFI]=20;
    zLevelHigh[TITAN_ZONELEVEL_HIFO]=32;
    zLevelLow[TITAN_ZONELEVEL_HIFO]=20;
    zLevelHigh[TITAN_ZONELEVEL_HIL]=30;
    zLevelLow[TITAN_ZONELEVEL_HIL]=26;
    zLevelHigh[TITAN_ZONELEVEL_HIWA]=47;
    zLevelLow[TITAN_ZONELEVEL_HIWA]=25;
    zLevelHigh[TITAN_ZONELEVEL_HOST]=18;
    zLevelLow[TITAN_ZONELEVEL_HOST]=13;
--<< I >>--
    zLevelHigh[TITAN_ZONELEVEL_ICTHHI]=58;
    zLevelLow[TITAN_ZONELEVEL_ICTHHI]=55;
    zLevelHigh[TITAN_ZONELEVEL_ICGA]=0;
    zLevelLow[TITAN_ZONELEVEL_ICGA]=0;
    zLevelHigh[TITAN_ZONELEVEL_ICLA]=10;
    zLevelLow[TITAN_ZONELEVEL_ICLA]=7;
    zLevelHigh[TITAN_ZONELEVEL_IDLA]=0;
    zLevelLow[TITAN_ZONELEVEL_IDLA]=0;
    zLevelHigh[TITAN_ZONELEVEL_IRLA]=22;
    zLevelLow[TITAN_ZONELEVEL_IRLA]=20;
    zLevelHigh[TITAN_ZONELEVEL_IRCO]=12;
    zLevelLow[TITAN_ZONELEVEL_IRCO]=9;
    zLevelHigh[TITAN_ZONELEVEL_IREXSI]=22;
    zLevelLow[TITAN_ZONELEVEL_IREXSI]=13;
    zLevelHigh[TITAN_ZONELEVEL_IRTO]=26;
    zLevelLow[TITAN_ZONELEVEL_IRTO]=22;
    zLevelHigh[TITAN_ZONELEVEL_IRO]=0;
    zLevelLow[TITAN_ZONELEVEL_IRO]=0;
    zLevelHigh[TITAN_ZONELEVEL_IRPL]=50;
    zLevelLow[TITAN_ZONELEVEL_IRPL]=48;
    zLevelHigh[TITAN_ZONELEVEL_IRCA]=54;
    zLevelLow[TITAN_ZONELEVEL_IRCA]=52;
    zLevelHigh[TITAN_ZONELEVEL_IRWO]=56;
    zLevelLow[TITAN_ZONELEVEL_IRWO]=1;
    zLevelHigh[TITAN_ZONELEVEL_ISOFLA]=0;
    zLevelLow[TITAN_ZONELEVEL_ISOFLA]=0;
    zLevelHigh[TITAN_ZONELEVEL_ISOF]=47;
    zLevelLow[TITAN_ZONELEVEL_ISOF]=43;
    zLevelHigh[TITAN_ZONELEVEL_ITCA]=37;
    zLevelLow[TITAN_ZONELEVEL_ITCA]=34;
--<< J >>--
    zLevelHigh[TITAN_ZONELEVEL_JAGL]=51;
    zLevelLow[TITAN_ZONELEVEL_JAGL]=47;
    zLevelHigh[TITAN_ZONELEVEL_JARU]=53;
    zLevelLow[TITAN_ZONELEVEL_JARU]=49;
    zLevelHigh[TITAN_ZONELEVEL_JALA]=62;
    zLevelLow[TITAN_ZONELEVEL_JALA]=60;
    zLevelHigh[TITAN_ZONELEVEL_JAE]=53;
    zLevelLow[TITAN_ZONELEVEL_JAE]=48;
    zLevelHigh[TITAN_ZONELEVEL_JARE]=54;
    zLevelLow[TITAN_ZONELEVEL_JARE]=50;
    zLevelHigh[TITAN_ZONELEVEL_JAFA]=11;
    zLevelLow[TITAN_ZONELEVEL_JAFA]=2;
    zLevelHigh[TITAN_ZONELEVEL_JAIS]=55;
    zLevelLow[TITAN_ZONELEVEL_JAIS]=50;
    zLevelHigh[TITAN_ZONELEVEL_JAPO]=50;
    zLevelLow[TITAN_ZONELEVEL_JAPO]=50;
    zLevelHigh[TITAN_ZONELEVEL_JANMI]=19;
    zLevelLow[TITAN_ZONELEVEL_JANMI]=10;
    zLevelHigh[TITAN_ZONELEVEL_JASMI]=8;
    zLevelLow[TITAN_ZONELEVEL_JASMI]=6;
    zLevelHigh[TITAN_ZONELEVEL_JELA]=10;
    zLevelLow[TITAN_ZONELEVEL_JELA]=8;
    zLevelHigh[TITAN_ZONELEVEL_JI]=53;
    zLevelLow[TITAN_ZONELEVEL_JI]=5;
--<< K >>--
    zLevelHigh[TITAN_ZONELEVEL_KARU]=36;
    zLevelLow[TITAN_ZONELEVEL_KARU]=35;
    zLevelHigh[TITAN_ZONELEVEL_KAKE]=30;
    zLevelLow[TITAN_ZONELEVEL_KAKE]=28;
    zLevelHigh[TITAN_ZONELEVEL_KAOU]=0;
    zLevelLow[TITAN_ZONELEVEL_KAOU]=0;
    zLevelHigh[TITAN_ZONELEVEL_KAR]=60;
    zLevelLow[TITAN_ZONELEVEL_KAR]=30;
    zLevelHigh[TITAN_ZONELEVEL_KHA]=30;
    zLevelLow[TITAN_ZONELEVEL_KHA]=5;
    zLevelHigh[TITAN_ZONELEVEL_KOGR]=38;
    zLevelLow[TITAN_ZONELEVEL_KOGR]=31;
    zLevelHigh[TITAN_ZONELEVEL_KOCR]=9;
    zLevelLow[TITAN_ZONELEVEL_KOCR]=2;
    zLevelHigh[TITAN_ZONELEVEL_KOVI]=33;
    zLevelLow[TITAN_ZONELEVEL_KOVI]=30;
    zLevelHigh[TITAN_ZONELEVEL_KOHU]=34;
    zLevelLow[TITAN_ZONELEVEL_KOHU]=30;
    zLevelHigh[TITAN_ZONELEVEL_KUCO]=35;
    zLevelLow[TITAN_ZONELEVEL_KUCO]=30;
--<< L >>--
    zLevelHigh[TITAN_ZONELEVEL_LAEV]=22;
    zLevelLow[TITAN_ZONELEVEL_LAEV]=16;
    zLevelHigh[TITAN_ZONELEVEL_LAFA]=20;
    zLevelLow[TITAN_ZONELEVEL_LAFA]=18;
    zLevelHigh[TITAN_ZONELEVEL_LAKE]=57;
    zLevelLow[TITAN_ZONELEVEL_LAKE]=54;
    zLevelHigh[TITAN_ZONELEVEL_LAMEN]=54;
    zLevelLow[TITAN_ZONELEVEL_LAMEN]=50;
    zLevelHigh[TITAN_ZONELEVEL_LAMER]=56;
    zLevelLow[TITAN_ZONELEVEL_LAMER]=53;
    zLevelHigh[TITAN_ZONELEVEL_LANA]=36;
    zLevelLow[TITAN_ZONELEVEL_LANA]=30;
    zLevelHigh[TITAN_ZONELEVEL_LAHI]=19;
    zLevelLow[TITAN_ZONELEVEL_LAHI]=14;
    zLevelHigh[TITAN_ZONELEVEL_LAK]=0;
    zLevelLow[TITAN_ZONELEVEL_LAK]=0;
    zLevelHigh[TITAN_ZONELEVEL_LATAPI]=61;
    zLevelLow[TITAN_ZONELEVEL_LATAPI]=48;
    zLevelHigh[TITAN_ZONELEVEL_LAENBE]=50;
    zLevelLow[TITAN_ZONELEVEL_LAENBE]=48;
    zLevelHigh[TITAN_ZONELEVEL_LAPA]=46;
    zLevelLow[TITAN_ZONELEVEL_LAPA]=40;
    zLevelHigh[TITAN_ZONELEVEL_LEEN]=51;
    zLevelLow[TITAN_ZONELEVEL_LEEN]=51;
    zLevelHigh[TITAN_ZONELEVEL_LERA]=57;
    zLevelLow[TITAN_ZONELEVEL_LERA]=41;
    zLevelHigh[TITAN_ZONELEVEL_LIHOCH]=62;
    zLevelLow[TITAN_ZONELEVEL_LIHOCH]=52;
    zLevelHigh[TITAN_ZONELEVEL_LIG]=0;
    zLevelLow[TITAN_ZONELEVEL_LIG]=0;
    zLevelHigh[TITAN_ZONELEVEL_LITAPI]=0;
    zLevelLow[TITAN_ZONELEVEL_LITAPI]=0;
    zLevelHigh[TITAN_ZONELEVEL_LOMO]=36;
    zLevelLow[TITAN_ZONELEVEL_LOMO]=10;
    zLevelHigh[TITAN_ZONELEVEL_LON]=19;
    zLevelLow[TITAN_ZONELEVEL_LON]=10;
    zLevelHigh[TITAN_ZONELEVEL_LOINCA]=36;
    zLevelLow[TITAN_ZONELEVEL_LOINCA]=24;
    zLevelHigh[TITAN_ZONELEVEL_LOLA]=35;
    zLevelLow[TITAN_ZONELEVEL_LOLA]=12;
    zLevelHigh[TITAN_ZONELEVEL_LOPO]=37;
    zLevelLow[TITAN_ZONELEVEL_LOPO]=37;
    zLevelHigh[TITAN_ZONELEVEL_LORICO]=54;
    zLevelLow[TITAN_ZONELEVEL_LORICO]=44;
    zLevelHigh[TITAN_ZONELEVEL_LOWI]=65;
    zLevelLow[TITAN_ZONELEVEL_LOWI]=36;
    zLevelHigh[TITAN_ZONELEVEL_LUOA]=30;
    zLevelLow[TITAN_ZONELEVEL_LUOA]=12;
--<< M >>--
    zLevelHigh[TITAN_ZONELEVEL_MAPO]=42;
    zLevelLow[TITAN_ZONELEVEL_MAPO]=18;
    zLevelHigh[TITAN_ZONELEVEL_MAVI]=37;
    zLevelLow[TITAN_ZONELEVEL_MAVI]=32;
    zLevelHigh[TITAN_ZONELEVEL_MAJI]=30;
    zLevelLow[TITAN_ZONELEVEL_MAJI]=20;
    zLevelHigh[TITAN_ZONELEVEL_MAOR]=12;
    zLevelLow[TITAN_ZONELEVEL_MAOR]=10;
    zLevelHigh[TITAN_ZONELEVEL_MACO]=40;
    zLevelLow[TITAN_ZONELEVEL_MACO]=30;
    zLevelHigh[TITAN_ZONELEVEL_MAMI]=30;
    zLevelLow[TITAN_ZONELEVEL_MAMI]=29;
    zLevelHigh[TITAN_ZONELEVEL_MARO]=0;
    zLevelLow[TITAN_ZONELEVEL_MARO]=0;
    zLevelHigh[TITAN_ZONELEVEL_MAR]=50;
    zLevelLow[TITAN_ZONELEVEL_MAR]=37;
    zLevelHigh[TITAN_ZONELEVEL_MARE]=54;
    zLevelLow[TITAN_ZONELEVEL_MARE]=51;
    zLevelHigh[TITAN_ZONELEVEL_MAAL]=59;
    zLevelLow[TITAN_ZONELEVEL_MAAL]=58;
    zLevelHigh[TITAN_ZONELEVEL_MAZ]=59;
    zLevelLow[TITAN_ZONELEVEL_MAZ]=56;
    zLevelHigh[TITAN_ZONELEVEL_MEBA]=29;
    zLevelLow[TITAN_ZONELEVEL_MEBA]=20;
    zLevelHigh[TITAN_ZONELEVEL_MEHA]=0;
    zLevelLow[TITAN_ZONELEVEL_MEHA]=0;
    zLevelHigh[TITAN_ZONELEVEL_MIFL]=55;
    zLevelLow[TITAN_ZONELEVEL_MIFL]=37;
    zLevelHigh[TITAN_ZONELEVEL_MILA]=25;
    zLevelLow[TITAN_ZONELEVEL_MILA]=14;
    zLevelHigh[TITAN_ZONELEVEL_MILAOR]=6;
    zLevelLow[TITAN_ZONELEVEL_MILAOR]=5;
    zLevelHigh[TITAN_ZONELEVEL_MILA]=9;
    zLevelLow[TITAN_ZONELEVEL_MILA]=5;
    zLevelHigh[TITAN_ZONELEVEL_MIED]=21;
    zLevelLow[TITAN_ZONELEVEL_MIED]=9;
    zLevelHigh[TITAN_ZONELEVEL_MIVA]=41;
    zLevelLow[TITAN_ZONELEVEL_MIVA]=40;
    zLevelHigh[TITAN_ZONELEVEL_MIPIRE]=8;
    zLevelLow[TITAN_ZONELEVEL_MIPIRE]=7;
    zLevelHigh[TITAN_ZONELEVEL_MIREPO]=53;
    zLevelLow[TITAN_ZONELEVEL_MIREPO]=39;
    zLevelHigh[TITAN_ZONELEVEL_MIREST]=53;
    zLevelLow[TITAN_ZONELEVEL_MIREST]=12;
    zLevelHigh[TITAN_ZONELEVEL_MISH]=31;
    zLevelLow[TITAN_ZONELEVEL_MISH]=30;
    zLevelHigh[TITAN_ZONELEVEL_MIVA]=42;
    zLevelLow[TITAN_ZONELEVEL_MIVA]=36;
    zLevelHigh[TITAN_ZONELEVEL_MIRU]=50;
    zLevelLow[TITAN_ZONELEVEL_MIRU]=1;
    zLevelHigh[TITAN_ZONELEVEL_MOST]=20;
    zLevelLow[TITAN_ZONELEVEL_MOST]=18;
    zLevelHigh[TITAN_ZONELEVEL_MOGO]=0;
    zLevelLow[TITAN_ZONELEVEL_MOGO]=0;
    zLevelHigh[TITAN_ZONELEVEL_MOB]=26;
    zLevelLow[TITAN_ZONELEVEL_MOB]=11;
    zLevelHigh[TITAN_ZONELEVEL_MON]=27;
    zLevelLow[TITAN_ZONELEVEL_MON]=23;
    zLevelHigh[TITAN_ZONELEVEL_MOVI]=0;
    zLevelLow[TITAN_ZONELEVEL_MOVI]=0;
    zLevelHigh[TITAN_ZONELEVEL_MOAR]=49;
    zLevelLow[TITAN_ZONELEVEL_MOAR]=47;
    zLevelHigh[TITAN_ZONELEVEL_MOOGMO]=42;
    zLevelLow[TITAN_ZONELEVEL_MOOGMO]=37;
    zLevelHigh[TITAN_ZONELEVEL_MOFE]=22;
    zLevelLow[TITAN_ZONELEVEL_MOFE]=20;
    zLevelHigh[TITAN_ZONELEVEL_MUL]=14;
    zLevelLow[TITAN_ZONELEVEL_MUL]=5;
    zLevelHigh[TITAN_ZONELEVEL_MYLA]=35;
    zLevelLow[TITAN_ZONELEVEL_MYLA]=21;
--<< N >>--
    zLevelHigh[TITAN_ZONELEVEL_NEWE]=44;
    zLevelLow[TITAN_ZONELEVEL_NEWE]=43;
    zLevelHigh[TITAN_ZONELEVEL_NEEX]=34;
    zLevelLow[TITAN_ZONELEVEL_NEEX]=30;
    zLevelHigh[TITAN_ZONELEVEL_NEST]=32;
    zLevelLow[TITAN_ZONELEVEL_NEST]=24;
    zLevelHigh[TITAN_ZONELEVEL_NEKE]=55;
    zLevelLow[TITAN_ZONELEVEL_NEKE]=55;
    zLevelHigh[TITAN_ZONELEVEL_NIRU]=26;
    zLevelLow[TITAN_ZONELEVEL_NIRU]=25;
    zLevelHigh[TITAN_ZONELEVEL_NIHO]=5;
    zLevelLow[TITAN_ZONELEVEL_NIHO]=2;
    zLevelHigh[TITAN_ZONELEVEL_NIVA]=6;
    zLevelLow[TITAN_ZONELEVEL_NIVA]=5;
    zLevelHigh[TITAN_ZONELEVEL_NIWO]=30;
    zLevelLow[TITAN_ZONELEVEL_NIWO]=20;
    zLevelHigh[TITAN_ZONELEVEL_NIPO]=45;
    zLevelLow[TITAN_ZONELEVEL_NIPO]=32;
    zLevelHigh[TITAN_ZONELEVEL_NORU]=43;
    zLevelLow[TITAN_ZONELEVEL_NORU]=40;
    zLevelHigh[TITAN_ZONELEVEL_NOGAOU]=18;
    zLevelLow[TITAN_ZONELEVEL_NOGAOU]=8;
    zLevelHigh[TITAN_ZONELEVEL_NOPOTO]=38;
    zLevelLow[TITAN_ZONELEVEL_NOPOTO]=35;
    zLevelHigh[TITAN_ZONELEVEL_NOTIHO]=25;
    zLevelLow[TITAN_ZONELEVEL_NOTIHO]=12;
    zLevelHigh[TITAN_ZONELEVEL_NOTIRU]=22;
    zLevelLow[TITAN_ZONELEVEL_NOTIRU]=12;
    zLevelHigh[TITAN_ZONELEVEL_NOR]=58;
    zLevelLow[TITAN_ZONELEVEL_NOR]=57;
    zLevelHigh[TITAN_ZONELEVEL_NOMA]=36;
    zLevelLow[TITAN_ZONELEVEL_NOMA]=30;
    zLevelHigh[TITAN_ZONELEVEL_NOLUCA]=56;
    zLevelLow[TITAN_ZONELEVEL_NOLUCA]=52;
    zLevelHigh[TITAN_ZONELEVEL_NORI]=0;
    zLevelLow[TITAN_ZONELEVEL_NORI]=0;
    zLevelHigh[TITAN_ZONELEVEL_NOVA]=10;
    zLevelLow[TITAN_ZONELEVEL_NOVA]=1;
    zLevelHigh[TITAN_ZONELEVEL_NOHO]=36;
    zLevelLow[TITAN_ZONELEVEL_NOHO]=13;
--<< O >>--
    zLevelHigh[TITAN_ZONELEVEL_OBCA]=0;
    zLevelLow[TITAN_ZONELEVEL_OBCA]=0;
    zLevelHigh[TITAN_ZONELEVEL_OLFA]=13;
    zLevelLow[TITAN_ZONELEVEL_OLFA]=11;
    zLevelHigh[TITAN_ZONELEVEL_ONE]=62;
    zLevelLow[TITAN_ZONELEVEL_ONE]=60;
    zLevelHigh[TITAN_ZONELEVEL_ONLA]=0;
    zLevelLow[TITAN_ZONELEVEL_ONLA]=0;
    zLevelHigh[TITAN_ZONELEVEL_ORG]=30;
    zLevelLow[TITAN_ZONELEVEL_ORG]=1;
    zLevelHigh[TITAN_ZONELEVEL_OWWITH]=59;
    zLevelLow[TITAN_ZONELEVEL_OWWITH]=56;
--<< P >>--
    zLevelHigh[TITAN_ZONELEVEL_PARO]=8;
    zLevelLow[TITAN_ZONELEVEL_PARO]=5;
    zLevelHigh[TITAN_ZONELEVEL_PESC]=56;
    zLevelLow[TITAN_ZONELEVEL_PESC]=54;
    zLevelHigh[TITAN_ZONELEVEL_PLA]=58;
    zLevelLow[TITAN_ZONELEVEL_PLA]=53;
    zLevelHigh[TITAN_ZONELEVEL_POTE]=62;
    zLevelLow[TITAN_ZONELEVEL_POTE]=37;
    zLevelHigh[TITAN_ZONELEVEL_PUIS]=31;
    zLevelLow[TITAN_ZONELEVEL_PUIS]=28;
    zLevelHigh[TITAN_ZONELEVEL_PYVI]=18;
    zLevelLow[TITAN_ZONELEVEL_PYVI]=12;
--<< Q >>--
    zLevelHigh[TITAN_ZONELEVEL_QUDA]=49;
    zLevelLow[TITAN_ZONELEVEL_QUDA]=12;
    zLevelHigh[TITAN_ZONELEVEL_QULI]=60;
    zLevelLow[TITAN_ZONELEVEL_QULI]=57;
--<< R >>--
    zLevelHigh[TITAN_ZONELEVEL_RASCHO]=49;
    zLevelLow[TITAN_ZONELEVEL_RASCHO]=46;
    zLevelHigh[TITAN_ZONELEVEL_RACH]=15
    zLevelLow[TITAN_ZONELEVEL_RACH]=13
    zLevelHigh[TITAN_ZONELEVEL_RAGR]=18;
    zLevelLow[TITAN_ZONELEVEL_RAGR]=16;
    zLevelHigh[TITAN_ZONELEVEL_RARI]=0;
    zLevelLow[TITAN_ZONELEVEL_RARI]=0;
    zLevelHigh[TITAN_ZONELEVEL_RAT]=45;
    zLevelLow[TITAN_ZONELEVEL_RAT]=13;
    zLevelHigh[TITAN_ZONELEVEL_RACA]=12;
    zLevelLow[TITAN_ZONELEVEL_RACA]=6;
    zLevelHigh[TITAN_ZONELEVEL_RAHICE]=35;
    zLevelLow[TITAN_ZONELEVEL_RAHICE]=19;
    zLevelHigh[TITAN_ZONELEVEL_RAVHI]=26;
    zLevelLow[TITAN_ZONELEVEL_RAVHI]=18;
    zLevelHigh[TITAN_ZONELEVEL_RAMO]=55;
    zLevelLow[TITAN_ZONELEVEL_RAMO]=53;
    zLevelHigh[TITAN_ZONELEVEL_RARE]=35;
    zLevelLow[TITAN_ZONELEVEL_RARE]=21;
    zLevelHigh[TITAN_ZONELEVEL_RAHIBA]=32;
    zLevelLow[TITAN_ZONELEVEL_RAHIBA]=14;
    zLevelHigh[TITAN_ZONELEVEL_RAZHI]=35;
    zLevelLow[TITAN_ZONELEVEL_RAZHI]=1;
    zLevelHigh[TITAN_ZONELEVEL_RADO]=40
    zLevelLow[TITAN_ZONELEVEL_RADO]=35
    zLevelHigh[TITAN_ZONELEVEL_RAKR]=34;
    zLevelLow[TITAN_ZONELEVEL_RAKR]=12;
    zLevelHigh[TITAN_ZONELEVEL_RAZ]=40;
    zLevelLow[TITAN_ZONELEVEL_RAZ]=23;
    zLevelHigh[TITAN_ZONELEVEL_RAZGR]=32;
    zLevelLow[TITAN_ZONELEVEL_RAZGR]=1;
    zLevelHigh[TITAN_ZONELEVEL_RAZCA]=8;
    zLevelLow[TITAN_ZONELEVEL_RAZCA]=4;
    zLevelHigh[TITAN_ZONELEVEL_RECA]=31;
    zLevelLow[TITAN_ZONELEVEL_RECA]=30;
    zLevelHigh[TITAN_ZONELEVEL_RECLME]=7;
    zLevelLow[TITAN_ZONELEVEL_RECLME]=1;
    zLevelHigh[TITAN_ZONELEVEL_RERO]=10;
    zLevelLow[TITAN_ZONELEVEL_RERO]=7;
    zLevelHigh[TITAN_ZONELEVEL_REDCA]=25;
    zLevelLow[TITAN_ZONELEVEL_REDCA]=16;
    zLevelHigh[TITAN_ZONELEVEL_REMO]=35;
    zLevelLow[TITAN_ZONELEVEL_REMO]=14;
    zLevelHigh[TITAN_ZONELEVEL_REPO]=39;
    zLevelLow[TITAN_ZONELEVEL_REPO]=30;
    zLevelHigh[TITAN_ZONELEVEL_REEXSI]=20;
    zLevelLow[TITAN_ZONELEVEL_REEXSI]=15;
    zLevelHigh[TITAN_ZONELEVEL_RENCA]=25;
    zLevelLow[TITAN_ZONELEVEL_RENCA]=16;
    zLevelHigh[TITAN_ZONELEVEL_RENRO]=25;
    zLevelLow[TITAN_ZONELEVEL_RENRO]=19;
    zLevelHigh[TITAN_ZONELEVEL_REVA]=22;
    zLevelLow[TITAN_ZONELEVEL_REVA]=17;
    zLevelHigh[TITAN_ZONELEVEL_RETCA]=24;
    zLevelLow[TITAN_ZONELEVEL_RETCA]=17;
    zLevelHigh[TITAN_ZONELEVEL_RITO]=11;
    zLevelLow[TITAN_ZONELEVEL_RITO]=8;
    zLevelHigh[TITAN_ZONELEVEL_RITH]=53;
    zLevelLow[TITAN_ZONELEVEL_RITH]=45;
    zLevelHigh[TITAN_ZONELEVEL_ROFA]=11;
    zLevelLow[TITAN_ZONELEVEL_ROFA]=5;
    zLevelHigh[TITAN_ZONELEVEL_ROG]=31;
    zLevelLow[TITAN_ZONELEVEL_ROG]=28;
    zLevelHigh[TITAN_ZONELEVEL_ROSO]=31;
    zLevelLow[TITAN_ZONELEVEL_ROSO]=30;
    zLevelHigh[TITAN_ZONELEVEL_RUAB]=44;
    zLevelLow[TITAN_ZONELEVEL_RUAB]=43;
    zLevelHigh[TITAN_ZONELEVEL_RUAL]=49;
    zLevelLow[TITAN_ZONELEVEL_RUAL]=32;
    zLevelHigh[TITAN_ZONELEVEL_RUANE]=60;
    zLevelLow[TITAN_ZONELEVEL_RUANE]=50;
    zLevelHigh[TITAN_ZONELEVEL_RUANO]=61;
    zLevelLow[TITAN_ZONELEVEL_RUANO]=52;
    zLevelHigh[TITAN_ZONELEVEL_RUCO]=54;
    zLevelLow[TITAN_ZONELEVEL_RUCO]=47;
    zLevelHigh[TITAN_ZONELEVEL_RUEL]=53;
    zLevelLow[TITAN_ZONELEVEL_RUEL]=46;
    zLevelHigh[TITAN_ZONELEVEL_RUIS]=47;
    zLevelLow[TITAN_ZONELEVEL_RUIS]=41;
    zLevelHigh[TITAN_ZONELEVEL_RUJU]=44;
    zLevelLow[TITAN_ZONELEVEL_RUJU]=43;
    zLevelHigh[TITAN_ZONELEVEL_RULO]=15;
    zLevelLow[TITAN_ZONELEVEL_RULO]=6;
    zLevelHigh[TITAN_ZONELEVEL_RUMA]=21;
    zLevelLow[TITAN_ZONELEVEL_RUMA]=17;
    zLevelHigh[TITAN_ZONELEVEL_RURA]=50;
    zLevelLow[TITAN_ZONELEVEL_RURA]=47;
    zLevelHigh[TITAN_ZONELEVEL_RUSO]=43;
    zLevelLow[TITAN_ZONELEVEL_RUSO]=40;
    zLevelHigh[TITAN_ZONELEVEL_RUTH]=57;
    zLevelLow[TITAN_ZONELEVEL_RUTH]=50;
    zLevelHigh[TITAN_ZONELEVEL_RUZUK]=41;
    zLevelLow[TITAN_ZONELEVEL_RUZUK]=32;
    zLevelHigh[TITAN_ZONELEVEL_RUZUM]=45;
    zLevelLow[TITAN_ZONELEVEL_RUZUM]=37;
--<< S >>--
    zLevelHigh[TITAN_ZONELEVEL_SAFA]=19;
    zLevelLow[TITAN_ZONELEVEL_SAFA]=10;
    zLevelHigh[TITAN_ZONELEVEL_SAGL]=26;
    zLevelLow[TITAN_ZONELEVEL_SAGL]=23;
    zLevelHigh[TITAN_ZONELEVEL_SAWA]=48;
    zLevelLow[TITAN_ZONELEVEL_SAWA]=41;
    zLevelHigh[TITAN_ZONELEVEL_SAST]=55;
    zLevelLow[TITAN_ZONELEVEL_SAST]=30;
    zLevelHigh[TITAN_ZONELEVEL_SAIS]=0;
    zLevelLow[TITAN_ZONELEVEL_SAIS]=0;
    zLevelHigh[TITAN_ZONELEVEL_SAR]=0;
    zLevelLow[TITAN_ZONELEVEL_SAR]=0;
    zLevelHigh[TITAN_ZONELEVEL_SAT]=30;
    zLevelLow[TITAN_ZONELEVEL_SAT]=26;
    zLevelHigh[TITAN_ZONELEVEL_SBA]=0;
    zLevelLow[TITAN_ZONELEVEL_SBA]=0;
    zLevelHigh[TITAN_ZONELEVEL_SCBACA]=54;
    zLevelLow[TITAN_ZONELEVEL_SCBACA]=53;
    zLevelHigh[TITAN_ZONELEVEL_SCMO]=40;
    zLevelLow[TITAN_ZONELEVEL_SCMO]=29;
    zLevelHigh[TITAN_ZONELEVEL_SCWAPO]=12;
    zLevelLow[TITAN_ZONELEVEL_SCWAPO]=8;
    zLevelHigh[TITAN_ZONELEVEL_SCH]=60
    zLevelLow[TITAN_ZONELEVEL_SCH]=57
    zLevelHigh[TITAN_ZONELEVEL_SCCA]=38;
    zLevelLow[TITAN_ZONELEVEL_SCCA]=34;
    zLevelHigh[TITAN_ZONELEVEL_SCCO]=13;
    zLevelLow[TITAN_ZONELEVEL_SCCO]=1;
    zLevelHigh[TITAN_ZONELEVEL_SEGO]=58;
    zLevelLow[TITAN_ZONELEVEL_SEGO]=43;
    zLevelHigh[TITAN_ZONELEVEL_SEVI]=50;
    zLevelLow[TITAN_ZONELEVEL_SEVI]=1;
    zLevelHigh[TITAN_ZONELEVEL_SEHI]=30;
    zLevelLow[TITAN_ZONELEVEL_SEHI]=10;
    zLevelHigh[TITAN_ZONELEVEL_SEPO]=34;
    zLevelLow[TITAN_ZONELEVEL_SEPO]=32;
    zLevelHigh[TITAN_ZONELEVEL_SER]=62;
    zLevelLow[TITAN_ZONELEVEL_SER]=60;
    zLevelHigh[TITAN_ZONELEVEL_SECO]=55;
    zLevelLow[TITAN_ZONELEVEL_SECO]=47;
    zLevelHigh[TITAN_ZONELEVEL_SHHO]=59;
    zLevelLow[TITAN_ZONELEVEL_SHHO]=50;
    zLevelHigh[TITAN_ZONELEVEL_SHKE]=27;
    zLevelLow[TITAN_ZONELEVEL_SHKE]=13;
    zLevelHigh[TITAN_ZONELEVEL_SHA]=0;
    zLevelLow[TITAN_ZONELEVEL_SHA]=0;
    zLevelHigh[TITAN_ZONELEVEL_SHVI]=60;
    zLevelLow[TITAN_ZONELEVEL_SHVI]=10;
    zLevelHigh[TITAN_ZONELEVEL_SHSH]=48;
    zLevelLow[TITAN_ZONELEVEL_SHSH]=45;
    zLevelHigh[TITAN_ZONELEVEL_SHAL]=55;
    zLevelLow[TITAN_ZONELEVEL_SHAL]=25;
    zLevelHigh[TITAN_ZONELEVEL_SHREIN]=0;
    zLevelLow[TITAN_ZONELEVEL_SHREIN]=0;
    zLevelHigh[TITAN_ZONELEVEL_SHSCVA]=54;
    zLevelLow[TITAN_ZONELEVEL_SHSCVA]=49;
    zLevelHigh[TITAN_ZONELEVEL_SHBE]=0;
    zLevelLow[TITAN_ZONELEVEL_SHBE]=0;
    zLevelHigh[TITAN_ZONELEVEL_SHRI]=10;
    zLevelLow[TITAN_ZONELEVEL_SHRI]=7;
    zLevelHigh[TITAN_ZONELEVEL_SHCA]=46;
    zLevelLow[TITAN_ZONELEVEL_SHCA]=45;
    zLevelHigh[TITAN_ZONELEVEL_SHDOFL]=12;
    zLevelLow[TITAN_ZONELEVEL_SHDOFL]=12;
    zLevelHigh[TITAN_ZONELEVEL_SHFAWA]=14;
    zLevelLow[TITAN_ZONELEVEL_SHFAWA]=12;
    zLevelHigh[TITAN_ZONELEVEL_SHTH]=52;
    zLevelLow[TITAN_ZONELEVEL_SHTH]=50;
    zLevelHigh[TITAN_ZONELEVEL_SISTMI]=15;
    zLevelLow[TITAN_ZONELEVEL_SISTMI]=10;
    zLevelHigh[TITAN_ZONELEVEL_SIFO]=25;
    zLevelLow[TITAN_ZONELEVEL_SIFO]=10;
    zLevelHigh[TITAN_ZONELEVEL_SIRE]=40;
    zLevelLow[TITAN_ZONELEVEL_SIRE]=40;
    zLevelHigh[TITAN_ZONELEVEL_SIOU]=24;
    zLevelLow[TITAN_ZONELEVEL_SIOU]=21;
    zLevelHigh[TITAN_ZONELEVEL_SICA]=22;
    zLevelLow[TITAN_ZONELEVEL_SICA]=14;
    zLevelHigh[TITAN_ZONELEVEL_SKRO]=48;
    zLevelLow[TITAN_ZONELEVEL_SKRO]=46;
    zLevelHigh[TITAN_ZONELEVEL_SKRI]=0;
    zLevelLow[TITAN_ZONELEVEL_SKRI]=0;
    zLevelHigh[TITAN_ZONELEVEL_SLHO]=0;
    zLevelLow[TITAN_ZONELEVEL_SLHO]=0;
    zLevelHigh[TITAN_ZONELEVEL_SLRO]=60;
    zLevelLow[TITAN_ZONELEVEL_SLRO]=50;
    zLevelHigh[TITAN_ZONELEVEL_SONA]=35;
    zLevelLow[TITAN_ZONELEVEL_SONA]=32;
    zLevelHigh[TITAN_ZONELEVEL_SOGL]=0;
    zLevelLow[TITAN_ZONELEVEL_SOGL]=0;
    zLevelHigh[TITAN_ZONELEVEL_SOFA]=7;
    zLevelLow[TITAN_ZONELEVEL_SOFA]=5;
    zLevelHigh[TITAN_ZONELEVEL_SOHI]=57;
    zLevelLow[TITAN_ZONELEVEL_SOHI]=50;
    zLevelHigh[TITAN_ZONELEVEL_SOR]=62;
    zLevelLow[TITAN_ZONELEVEL_SOR]=37;
    zLevelHigh[TITAN_ZONELEVEL_SOGAOU]=10;
    zLevelLow[TITAN_ZONELEVEL_SOGAOU]=9;
    zLevelHigh[TITAN_ZONELEVEL_SOGAPA]=10;
    zLevelLow[TITAN_ZONELEVEL_SOGAPA]=9;
    zLevelHigh[TITAN_ZONELEVEL_SOTIRU]=0;
    zLevelLow[TITAN_ZONELEVEL_SOTIRU]=0;
    zLevelHigh[TITAN_ZONELEVEL_SOSH]=50;
    zLevelLow[TITAN_ZONELEVEL_SOSH]=48;
    zLevelHigh[TITAN_ZONELEVEL_SOBA]=45;
    zLevelLow[TITAN_ZONELEVEL_SOBA]=8;
    zLevelHigh[TITAN_ZONELEVEL_SOGORO]=34;
    zLevelLow[TITAN_ZONELEVEL_SOGORO]=14;
    zLevelHigh[TITAN_ZONELEVEL_SOSACO]=44;
    zLevelLow[TITAN_ZONELEVEL_SOSACO]=39;
    zLevelHigh[TITAN_ZONELEVEL_SORI]=48;
    zLevelLow[TITAN_ZONELEVEL_SORI]=4;
    zLevelHigh[TITAN_ZONELEVEL_SORU]=50;
    zLevelLow[TITAN_ZONELEVEL_SORU]=43;
    zLevelHigh[TITAN_ZONELEVEL_SOTO]=22;
    zLevelLow[TITAN_ZONELEVEL_SOTO]=21;
    zLevelHigh[TITAN_ZONELEVEL_SOBE]=55;
    zLevelLow[TITAN_ZONELEVEL_SOBE]=50;
    zLevelHigh[TITAN_ZONELEVEL_SOU]=38;
    zLevelLow[TITAN_ZONELEVEL_SOU]=22;
    zLevelHigh[TITAN_ZONELEVEL_SPRO]=15;
    zLevelLow[TITAN_ZONELEVEL_SPRO]=13;
    zLevelHigh[TITAN_ZONELEVEL_SPI]=44;
    zLevelLow[TITAN_ZONELEVEL_SPI]=40;
    zLevelHigh[TITAN_ZONELEVEL_SPJU]=37;
    zLevelLow[TITAN_ZONELEVEL_SPJU]=34;
    zLevelHigh[TITAN_ZONELEVEL_SPPO]=44;
    zLevelLow[TITAN_ZONELEVEL_SPPO]=26;
    zLevelHigh[TITAN_ZONELEVEL_SPCR]=27;
    zLevelLow[TITAN_ZONELEVEL_SPCR]=24;
    zLevelHigh[TITAN_ZONELEVEL_SPHO]=30;
    zLevelLow[TITAN_ZONELEVEL_SPHO]=24;
    zLevelHigh[TITAN_ZONELEVEL_STCA]=55;
    zLevelLow[TITAN_ZONELEVEL_STCA]=40;
    zLevelHigh[TITAN_ZONELEVEL_STA]=55;
    zLevelLow[TITAN_ZONELEVEL_STA]=30;
    zLevelHigh[TITAN_ZONELEVEL_STAVA]=55;
    zLevelLow[TITAN_ZONELEVEL_STAVA]=30;
    zLevelHigh[TITAN_ZONELEVEL_STVI]=56;
    zLevelLow[TITAN_ZONELEVEL_STVI]=54;
    zLevelHigh[TITAN_ZONELEVEL_STPO]=53;
    zLevelLow[TITAN_ZONELEVEL_STPO]=30;
    zLevelHigh[TITAN_ZONELEVEL_STSE]=8;
    zLevelLow[TITAN_ZONELEVEL_STSE]=5;
    zLevelHigh[TITAN_ZONELEVEL_STEPO]=17;
    zLevelLow[TITAN_ZONELEVEL_STEPO]=11;
    zLevelHigh[TITAN_ZONELEVEL_STIPO]=8;
    zLevelLow[TITAN_ZONELEVEL_STIPO]=5;
    zLevelHigh[TITAN_ZONELEVEL_STO]=60;
    zLevelLow[TITAN_ZONELEVEL_STO]=30;
    zLevelHigh[TITAN_ZONELEVEL_STCALA]=10;
    zLevelLow[TITAN_ZONELEVEL_STCALA]=7;
    zLevelHigh[TITAN_ZONELEVEL_STLA]=14;
    zLevelLow[TITAN_ZONELEVEL_STLA]=5;
    zLevelHigh[TITAN_ZONELEVEL_STOVA]=17;
    zLevelLow[TITAN_ZONELEVEL_STOVA]=11;
    zLevelHigh[TITAN_ZONELEVEL_STMO]=24;
    zLevelLow[TITAN_ZONELEVEL_STMO]=21;
    zLevelHigh[TITAN_ZONELEVEL_STPE]=27;
    zLevelLow[TITAN_ZONELEVEL_STPE]=22;
    zLevelHigh[TITAN_ZONELEVEL_STFA]=22;
    zLevelLow[TITAN_ZONELEVEL_STFA]=19;
    zLevelHigh[TITAN_ZONELEVEL_STKE]=26;
    zLevelLow[TITAN_ZONELEVEL_STKE]=21;
    zLevelHigh[TITAN_ZONELEVEL_STTO]=26;
    zLevelLow[TITAN_ZONELEVEL_STTO]=16;
    zLevelHigh[TITAN_ZONELEVEL_STW]=26;
    zLevelLow[TITAN_ZONELEVEL_STW]=20;
    zLevelHigh[TITAN_ZONELEVEL_STPA]=0;
    zLevelLow[TITAN_ZONELEVEL_STPA]=0;
    zLevelHigh[TITAN_ZONELEVEL_STG]=30;
    zLevelLow[TITAN_ZONELEVEL_STG]=10;
    zLevelHigh[TITAN_ZONELEVEL_STCI]=0;
    zLevelLow[TITAN_ZONELEVEL_STCI]=0;
    zLevelHigh[TITAN_ZONELEVEL_STR]=37;
    zLevelLow[TITAN_ZONELEVEL_STR]=34;
    zLevelHigh[TITAN_ZONELEVEL_STRVA]=45;
    zLevelLow[TITAN_ZONELEVEL_STRVA]=30;
    zLevelHigh[TITAN_ZONELEVEL_STH]=60;
    zLevelLow[TITAN_ZONELEVEL_STH]=55;
    zLevelHigh[TITAN_ZONELEVEL_STKE]=40;
    zLevelLow[TITAN_ZONELEVEL_STKE]=35;
    zLevelHigh[TITAN_ZONELEVEL_SURORE]=55;
    zLevelLow[TITAN_ZONELEVEL_SURORE]=17;
    zLevelHigh[TITAN_ZONELEVEL_SUMA]=26;
    zLevelLow[TITAN_ZONELEVEL_SUMA]=21;
    zLevelHigh[TITAN_ZONELEVEL_SWSO]=62;
    zLevelLow[TITAN_ZONELEVEL_SWSO]=25;
--<< T >>--
    zLevelHigh[TITAN_ZONELEVEL_TAGL]=53;
    zLevelLow[TITAN_ZONELEVEL_TAGL]=52;
    zLevelHigh[TITAN_ZONELEVEL_TAN]=50;
    zLevelLow[TITAN_ZONELEVEL_TAN]=40;
    zLevelHigh[TITAN_ZONELEVEL_TAMI]=56;
    zLevelLow[TITAN_ZONELEVEL_TAMI]=20;
    zLevelHigh[TITAN_ZONELEVEL_TEL]=10;
    zLevelLow[TITAN_ZONELEVEL_TEL]=1;
    zLevelHigh[TITAN_ZONELEVEL_TEAZ]=60;
    zLevelLow[TITAN_ZONELEVEL_TEAZ]=53;
    zLevelHigh[TITAN_ZONELEVEL_TEZM]=55;
    zLevelLow[TITAN_ZONELEVEL_TEZM]=48;
    zLevelHigh[TITAN_ZONELEVEL_TERE]=30;
    zLevelLow[TITAN_ZONELEVEL_TERE]=29;
    zLevelHigh[TITAN_ZONELEVEL_TERU]=55;
    zLevelLow[TITAN_ZONELEVEL_TERU]=50;
    zLevelHigh[TITAN_ZONELEVEL_TEWP]=55;
    zLevelLow[TITAN_ZONELEVEL_TEWP]=50;
    zLevelHigh[TITAN_ZONELEVEL_TER]=58;
    zLevelLow[TITAN_ZONELEVEL_TER]=53;
    zLevelHigh[TITAN_ZONELEVEL_TEAR]=0;
    zLevelLow[TITAN_ZONELEVEL_TEAR]=0;
    zLevelHigh[TITAN_ZONELEVEL_THA]=0;
    zLevelLow[TITAN_ZONELEVEL_THA]=0;
    zLevelHigh[TITAN_ZONELEVEL_THBC]=53;
    zLevelLow[TITAN_ZONELEVEL_THBC]=51;
    zLevelHigh[TITAN_ZONELEVEL_THSP]=22;
    zLevelLow[TITAN_ZONELEVEL_THSP]=22;
    zLevelHigh[TITAN_ZONELEVEL_THEAZ]=52;
    zLevelLow[TITAN_ZONELEVEL_THEAZ]=44;
    zLevelHigh[TITAN_ZONELEVEL_THEBA]=35;
    zLevelLow[TITAN_ZONELEVEL_THEBA]=5;
    zLevelHigh[TITAN_ZONELEVEL_THEBU]=60;
    zLevelLow[TITAN_ZONELEVEL_THEBU]=50;
    zLevelHigh[TITAN_ZONELEVEL_THECAST]=55;
    zLevelLow[TITAN_ZONELEVEL_THECAST]=37;
    zLevelHigh[TITAN_ZONELEVEL_THECEM]=0;
    zLevelLow[TITAN_ZONELEVEL_THECEM]=0;
    zLevelHigh[TITAN_ZONELEVEL_THECHVA]=30;
    zLevelLow[TITAN_ZONELEVEL_THECHVA]=23;
    zLevelHigh[TITAN_ZONELEVEL_THECRRU]=46;
    zLevelLow[TITAN_ZONELEVEL_THECRRU]=44;
    zLevelHigh[TITAN_ZONELEVEL_THECRO]=55;
    zLevelLow[TITAN_ZONELEVEL_THECRO]=10;
    zLevelHigh[TITAN_ZONELEVEL_THECRSH]=47;
    zLevelLow[TITAN_ZONELEVEL_THECRSH]=40;
    zLevelHigh[TITAN_ZONELEVEL_THEFALO]=15;
    zLevelLow[TITAN_ZONELEVEL_THEFALO]=15;
    zLevelHigh[TITAN_ZONELEVEL_THEFOCA]=0;
    zLevelLow[TITAN_ZONELEVEL_THEFOCA]=0;
    zLevelHigh[TITAN_ZONELEVEL_THEFOCO]=49;
    zLevelLow[TITAN_ZONELEVEL_THEFOCO]=41;
    zLevelHigh[TITAN_ZONELEVEL_THEFOPO]=17;
    zLevelLow[TITAN_ZONELEVEL_THEFOPO]=12;
    zLevelHigh[TITAN_ZONELEVEL_THEFUVA]=59;
    zLevelLow[TITAN_ZONELEVEL_THEFUVA]=57;
    zLevelHigh[TITAN_ZONELEVEL_THEGACH]=50;
    zLevelLow[TITAN_ZONELEVEL_THEGACH]=44;
    zLevelHigh[TITAN_ZONELEVEL_THEGOPL]=12;
    zLevelLow[TITAN_ZONELEVEL_THEGOPL]=6;
    zLevelHigh[TITAN_ZONELEVEL_THEGRLI]=27;
    zLevelLow[TITAN_ZONELEVEL_THEGRLI]=25;
    zLevelHigh[TITAN_ZONELEVEL_THEGRBE]=27;
    zLevelLow[TITAN_ZONELEVEL_THEGRBE]=21;
    zLevelHigh[TITAN_ZONELEVEL_THEGRWA]=25;
    zLevelLow[TITAN_ZONELEVEL_THEGRWA]=15;
    zLevelHigh[TITAN_ZONELEVEL_THEGRQU]=50;
    zLevelLow[TITAN_ZONELEVEL_THEGRQU]=47;
    zLevelHigh[TITAN_ZONELEVEL_THEGRZ]=7;
    zLevelLow[TITAN_ZONELEVEL_THEGRZ]=5;
    zLevelHigh[TITAN_ZONELEVEL_THEHA]=42;
    zLevelLow[TITAN_ZONELEVEL_THEHA]=35;
    zLevelHigh[TITAN_ZONELEVEL_THEHE]=34;
    zLevelLow[TITAN_ZONELEVEL_THEHE]=23;
    zLevelHigh[TITAN_ZONELEVEL_THEHIGR]=58;
    zLevelLow[TITAN_ZONELEVEL_THEHIGR]=56;
    zLevelHigh[TITAN_ZONELEVEL_THEHIN]=48;
    zLevelLow[TITAN_ZONELEVEL_THEHIN]=12;
    zLevelHigh[TITAN_ZONELEVEL_THEHOVA]=0;
    zLevelLow[TITAN_ZONELEVEL_THEHOVA]=0;
    zLevelHigh[TITAN_ZONELEVEL_THEHUBA]=22;
    zLevelLow[TITAN_ZONELEVEL_THEHUBA]=18;
    zLevelHigh[TITAN_ZONELEVEL_THEINSC]=56;
    zLevelLow[TITAN_ZONELEVEL_THEINSC]=54;
    zLevelHigh[TITAN_ZONELEVEL_THEIVPA]=15;
    zLevelLow[TITAN_ZONELEVEL_THEIVPA]=11;
    zLevelHigh[TITAN_ZONELEVEL_THEJAST]=13;
    zLevelLow[TITAN_ZONELEVEL_THEJAST]=9;
    zLevelHigh[TITAN_ZONELEVEL_THELOC]=22;
    zLevelLow[TITAN_ZONELEVEL_THELOC]=10;
    zLevelHigh[TITAN_ZONELEVEL_THELOWA]=13;
    zLevelLow[TITAN_ZONELEVEL_THELOWA]=10;
    zLevelHigh[TITAN_ZONELEVEL_THELOFL]=28;
    zLevelLow[TITAN_ZONELEVEL_THELOFL]=21;
    zLevelHigh[TITAN_ZONELEVEL_THEMAVI]=20;
    zLevelLow[TITAN_ZONELEVEL_THEMAVI]=5;
    zLevelHigh[TITAN_ZONELEVEL_THEMATE]=37;
    zLevelLow[TITAN_ZONELEVEL_THEMATE]=35;
    zLevelHigh[TITAN_ZONELEVEL_THEMAST]=62;
    zLevelLow[TITAN_ZONELEVEL_THEMAST]=53;
    zLevelHigh[TITAN_ZONELEVEL_THEMAR]=61;
    zLevelLow[TITAN_ZONELEVEL_THEMAR]=48;
    zLevelHigh[TITAN_ZONELEVEL_THEMAS]=50;
    zLevelLow[TITAN_ZONELEVEL_THEMAS]=48;
    zLevelHigh[TITAN_ZONELEVEL_THEMAGL]=20;
    zLevelLow[TITAN_ZONELEVEL_THEMAGL]=16;
    zLevelHigh[TITAN_ZONELEVEL_THEMECO]=38;
    zLevelLow[TITAN_ZONELEVEL_THEMECO]=12;
    zLevelHigh[TITAN_ZONELEVEL_THEMOFA]=19;
    zLevelLow[TITAN_ZONELEVEL_THEMOFA]=10;
    zLevelHigh[TITAN_ZONELEVEL_THEMOSP]=49;
    zLevelLow[TITAN_ZONELEVEL_THEMOSP]=48;
    zLevelHigh[TITAN_ZONELEVEL_THEMORA]=21;
    zLevelLow[TITAN_ZONELEVEL_THEMORA]=11;
    zLevelHigh[TITAN_ZONELEVEL_THENOCO]=9;
    zLevelLow[TITAN_ZONELEVEL_THENOCO]=7;
    zLevelHigh[TITAN_ZONELEVEL_THENOLA]=50;
    zLevelLow[TITAN_ZONELEVEL_THENOLA]=44;
    zLevelHigh[TITAN_ZONELEVEL_THEOVCL]=50;
    zLevelLow[TITAN_ZONELEVEL_THEOVCL]=30;
    zLevelHigh[TITAN_ZONELEVEL_THEPA]=57;
    zLevelLow[TITAN_ZONELEVEL_THEPA]=55;
    zLevelHigh[TITAN_ZONELEVEL_THEQU]=45;
    zLevelLow[TITAN_ZONELEVEL_THEQU]=36;
    zLevelHigh[TITAN_ZONELEVEL_THEROPL]=12;
    zLevelLow[TITAN_ZONELEVEL_THEROPL]=5;
    zLevelHigh[TITAN_ZONELEVEL_THEROOR]=29;
    zLevelLow[TITAN_ZONELEVEL_THEROOR]=26;
    zLevelHigh[TITAN_ZONELEVEL_THERURE]=55;
    zLevelLow[TITAN_ZONELEVEL_THERURE]=45;
    zLevelHigh[TITAN_ZONELEVEL_THERUKT]=56;
    zLevelLow[TITAN_ZONELEVEL_THERUKT]=54;
    zLevelHigh[TITAN_ZONELEVEL_THERULO]=13;
    zLevelLow[TITAN_ZONELEVEL_THERULO]=6;
    zLevelHigh[TITAN_ZONELEVEL_THERUOR]=19;
    zLevelLow[TITAN_ZONELEVEL_THERUOR]=18;
    zLevelHigh[TITAN_ZONELEVEL_THERUST]=24;
    zLevelLow[TITAN_ZONELEVEL_THERUST]=21;
    zLevelHigh[TITAN_ZONELEVEL_THERUSI]=35;
    zLevelLow[TITAN_ZONELEVEL_THERUSI]=32;
    zLevelHigh[TITAN_ZONELEVEL_THESASA]=50;
    zLevelLow[TITAN_ZONELEVEL_THESASA]=50;
    zLevelHigh[TITAN_ZONELEVEL_THESAN]=44;
    zLevelLow[TITAN_ZONELEVEL_THESAN]=39;
    zLevelHigh[TITAN_ZONELEVEL_THESACO]=55;
    zLevelLow[TITAN_ZONELEVEL_THESACO]=31;
    zLevelHigh[TITAN_ZONELEVEL_THESCMO]=40
    zLevelLow[TITAN_ZONELEVEL_THESCMO]=30
    zLevelHigh[TITAN_ZONELEVEL_THESCCA]=30;
    zLevelLow[TITAN_ZONELEVEL_THESCCA]=26;
    zLevelHigh[TITAN_ZONELEVEL_THESEP]=22;
    zLevelLow[TITAN_ZONELEVEL_THESEP]=10;
    zLevelHigh[TITAN_ZONELEVEL_THESHNO]=26;
    zLevelLow[TITAN_ZONELEVEL_THESHNO]=24;
    zLevelHigh[TITAN_ZONELEVEL_THESHAST]=52;
    zLevelLow[TITAN_ZONELEVEL_THESHAST]=50;
    zLevelHigh[TITAN_ZONELEVEL_THESHMI]=55;
    zLevelLow[TITAN_ZONELEVEL_THESHMI]=34;
    zLevelHigh[TITAN_ZONELEVEL_THESHFL]=37;
    zLevelLow[TITAN_ZONELEVEL_THESHFL]=27;
    zLevelHigh[TITAN_ZONELEVEL_THESHIST]=19;
    zLevelLow[TITAN_ZONELEVEL_THESHIST]=10;
    zLevelHigh[TITAN_ZONELEVEL_THESHAE]=27;
    zLevelLow[TITAN_ZONELEVEL_THESHAE]=17;
    zLevelHigh[TITAN_ZONELEVEL_THESKT]=15;
    zLevelLow[TITAN_ZONELEVEL_THESKT]=12;
    zLevelHigh[TITAN_ZONELEVEL_THESLSC]=53;
    zLevelLow[TITAN_ZONELEVEL_THESLSC]=48;
    zLevelHigh[TITAN_ZONELEVEL_THESLFE]=19;
    zLevelLow[TITAN_ZONELEVEL_THESLFE]=13;
    zLevelHigh[TITAN_ZONELEVEL_THESTOA]=18;
    zLevelLow[TITAN_ZONELEVEL_THESTOA]=12;
    zLevelHigh[TITAN_ZONELEVEL_THESTO]=26
    zLevelLow[TITAN_ZONELEVEL_THESTO]=23
    zLevelHigh[TITAN_ZONELEVEL_THESTFA]=9;
    zLevelLow[TITAN_ZONELEVEL_THESTFA]=5;
    zLevelHigh[TITAN_ZONELEVEL_THESUTE]=50
    zLevelLow[TITAN_ZONELEVEL_THESUTE]=44
    zLevelHigh[TITAN_ZONELEVEL_THETASC]=61;
    zLevelLow[TITAN_ZONELEVEL_THETASC]=61;
    zLevelHigh[TITAN_ZONELEVEL_THETAPA]=25;
    zLevelLow[TITAN_ZONELEVEL_THETAPA]=14;
    zLevelHigh[TITAN_ZONELEVEL_THETAL]=30;
    zLevelLow[TITAN_ZONELEVEL_THETAL]=22;
    zLevelHigh[TITAN_ZONELEVEL_THETIST]=36;
    zLevelLow[TITAN_ZONELEVEL_THETIST]=13;
    zLevelHigh[TITAN_ZONELEVEL_THETOAR]=40;
    zLevelLow[TITAN_ZONELEVEL_THETOAR]=37;
    zLevelHigh[TITAN_ZONELEVEL_THETUHI]=12;
    zLevelLow[TITAN_ZONELEVEL_THETUHI]=5;
    zLevelHigh[TITAN_ZONELEVEL_THETWCO]=50;
    zLevelLow[TITAN_ZONELEVEL_THETWCO]=44;
    zLevelHigh[TITAN_ZONELEVEL_THEUND]=55;
    zLevelLow[TITAN_ZONELEVEL_THEUND]=53;
    zLevelHigh[TITAN_ZONELEVEL_THEUPL]=37;
    zLevelLow[TITAN_ZONELEVEL_THEUPL]=30;
    zLevelHigh[TITAN_ZONELEVEL_THEVESE]=35;
    zLevelLow[TITAN_ZONELEVEL_THEVESE]=33;
    zLevelHigh[TITAN_ZONELEVEL_THEVEMI]=12;
    zLevelLow[TITAN_ZONELEVEL_THEVEMI]=6;
    zLevelHigh[TITAN_ZONELEVEL_THEVIRE]=40;
    zLevelLow[TITAN_ZONELEVEL_THEVIRE]=35;
    zLevelHigh[TITAN_ZONELEVEL_THEWACA]=27;
    zLevelLow[TITAN_ZONELEVEL_THEWACA]=15;
    zLevelHigh[TITAN_ZONELEVEL_THEWENO]=0;
    zLevelLow[TITAN_ZONELEVEL_THEWENO]=0;
    zLevelHigh[TITAN_ZONELEVEL_THEWHES]=0;
    zLevelLow[TITAN_ZONELEVEL_THEWHES]=0;
    zLevelHigh[TITAN_ZONELEVEL_THEWOTR]=0;
    zLevelLow[TITAN_ZONELEVEL_THEWOTR]=0;
    zLevelHigh[TITAN_ZONELEVEL_THEWRHA]=55;
    zLevelLow[TITAN_ZONELEVEL_THEWRHA]=52;
    zLevelHigh[TITAN_ZONELEVEL_THEWRI]=46;
    zLevelLow[TITAN_ZONELEVEL_THEWRI]=42;
    zLevelHigh[TITAN_ZONELEVEL_THEYOFA]=35;
    zLevelLow[TITAN_ZONELEVEL_THEYOFA]=23;
    zLevelHigh[TITAN_ZONELEVEL_THEZOST]=40;
    zLevelLow[TITAN_ZONELEVEL_THEZOST]=18;
    zLevelHigh[TITAN_ZONELEVEL_THHEHI]=30;
    zLevelLow[TITAN_ZONELEVEL_THHEHI]=15;
    zLevelHigh[TITAN_ZONELEVEL_THHEBA]=21;
    zLevelLow[TITAN_ZONELEVEL_THHEBA]=9;
    zLevelHigh[TITAN_ZONELEVEL_THHEAIS]=31;
    zLevelLow[TITAN_ZONELEVEL_THHEAIS]=15;
    zLevelHigh[TITAN_ZONELEVEL_THHEAC]=26;
    zLevelLow[TITAN_ZONELEVEL_THHEAC]=16;
    zLevelHigh[TITAN_ZONELEVEL_THHEFI]=14;
    zLevelLow[TITAN_ZONELEVEL_THHEFI]=11;
    zLevelHigh[TITAN_ZONELEVEL_THHEE]=22;
    zLevelLow[TITAN_ZONELEVEL_THHEE]=15;
    zLevelHigh[TITAN_ZONELEVEL_THHEFE]=16;
    zLevelLow[TITAN_ZONELEVEL_THHEFE]=13;
    zLevelHigh[TITAN_ZONELEVEL_THHERO]=22;
    zLevelLow[TITAN_ZONELEVEL_THHERO]=20;
    zLevelHigh[TITAN_ZONELEVEL_THHEL]=30;
    zLevelLow[TITAN_ZONELEVEL_THHEL]=10;
    zLevelHigh[TITAN_ZONELEVEL_THHEDABA]=32;
    zLevelLow[TITAN_ZONELEVEL_THHEDABA]=19;
    zLevelHigh[TITAN_ZONELEVEL_THHEER]=45;
    zLevelLow[TITAN_ZONELEVEL_THHEER]=37;
    zLevelHigh[TITAN_ZONELEVEL_THHERIS]=55;
    zLevelLow[TITAN_ZONELEVEL_THHERIS]=35;
    zLevelHigh[TITAN_ZONELEVEL_THHERE]=39;
    zLevelLow[TITAN_ZONELEVEL_THHERE]=39;
    zLevelHigh[TITAN_ZONELEVEL_THHEHIL]=20;
    zLevelLow[TITAN_ZONELEVEL_THHEHIL]=13;
    zLevelHigh[TITAN_ZONELEVEL_THHEPL]=24;
    zLevelLow[TITAN_ZONELEVEL_THHEPL]=15;
    zLevelHigh[TITAN_ZONELEVEL_THHEU]=55;
    zLevelLow[TITAN_ZONELEVEL_THHEU]=36;
    zLevelHigh[TITAN_ZONELEVEL_THICA]=0;
    zLevelLow[TITAN_ZONELEVEL_THICA]=0;
    zLevelHigh[TITAN_ZONELEVEL_THIVI]=25;
    zLevelLow[TITAN_ZONELEVEL_THIVI]=20;
    zLevelHigh[TITAN_ZONELEVEL_THIVA]=50;
    zLevelLow[TITAN_ZONELEVEL_THIVA]=47;
    zLevelHigh[TITAN_ZONELEVEL_THORI]=56;
    zLevelLow[TITAN_ZONELEVEL_THORI]=53;
    zLevelHigh[TITAN_ZONELEVEL_THOWA]=33;
    zLevelLow[TITAN_ZONELEVEL_THOWA]=24;
    zLevelHigh[TITAN_ZONELEVEL_THOHI]=19;
    zLevelLow[TITAN_ZONELEVEL_THOHI]=10;
    zLevelHigh[TITAN_ZONELEVEL_THONE]=42;
    zLevelLow[TITAN_ZONELEVEL_THONE]=10;
    zLevelHigh[TITAN_ZONELEVEL_THRCO]=35;
    zLevelLow[TITAN_ZONELEVEL_THRCO]=14;
    zLevelHigh[TITAN_ZONELEVEL_THUAXFO]=32;
    zLevelLow[TITAN_ZONELEVEL_THUAXFO]=30;
    zLevelHigh[TITAN_ZONELEVEL_THUBL]=75;
    zLevelLow[TITAN_ZONELEVEL_THUBL]=3;
    zLevelHigh[TITAN_ZONELEVEL_THUFA]=0;
    zLevelLow[TITAN_ZONELEVEL_THUFA]=0;
    zLevelHigh[TITAN_ZONELEVEL_THURI]=12;
    zLevelLow[TITAN_ZONELEVEL_THURI]=2;
    zLevelHigh[TITAN_ZONELEVEL_THUN]=30;
    zLevelLow[TITAN_ZONELEVEL_THUN]=30;
    zLevelHigh[TITAN_ZONELEVEL_THUWAWE]=12;
    zLevelLow[TITAN_ZONELEVEL_THUWAWE]=6;
    zLevelHigh[TITAN_ZONELEVEL_TICO]=43;
    zLevelLow[TITAN_ZONELEVEL_TICO]=42;
    zLevelHigh[TITAN_ZONELEVEL_TIHO]=55;
    zLevelLow[TITAN_ZONELEVEL_TIHO]=48;
    zLevelHigh[TITAN_ZONELEVEL_TIPO]=56;
    zLevelLow[TITAN_ZONELEVEL_TIPO]=53;
    zLevelHigh[TITAN_ZONELEVEL_TIKE]=9;
    zLevelLow[TITAN_ZONELEVEL_TIKE]=1;
    zLevelHigh[TITAN_ZONELEVEL_TIGL]=45;
    zLevelLow[TITAN_ZONELEVEL_TIGL]=5;
    zLevelHigh[TITAN_ZONELEVEL_TKRU]=37;
    zLevelLow[TITAN_ZONELEVEL_TKRU]=30;
    zLevelHigh[TITAN_ZONELEVEL_TOAL]=28;
    zLevelLow[TITAN_ZONELEVEL_TOAL]=16;
    zLevelHigh[TITAN_ZONELEVEL_TOAZ]=8;
    zLevelLow[TITAN_ZONELEVEL_TOAZ]=6;
    zLevelHigh[TITAN_ZONELEVEL_TOEL]=0;
    zLevelLow[TITAN_ZONELEVEL_TOEL]=0;
    zLevelHigh[TITAN_ZONELEVEL_TOIL]=26;
    zLevelLow[TITAN_ZONELEVEL_TOIL]=25;
    zLevelHigh[TITAN_ZONELEVEL_TRGACE]=30;
    zLevelLow[TITAN_ZONELEVEL_TRGACE]=21;
    zLevelHigh[TITAN_ZONELEVEL_TWGR]=0;
    zLevelLow[TITAN_ZONELEVEL_TWGR]=0;
    zLevelHigh[TITAN_ZONELEVEL_TWSH]=21;
    zLevelLow[TITAN_ZONELEVEL_TWSH]=10;
    zLevelHigh[TITAN_ZONELEVEL_TWVA]=20;
    zLevelLow[TITAN_ZONELEVEL_TWVA]=10;
--<< U >>--
    zLevelHigh[TITAN_ZONELEVEL_ULDA]=50;
    zLevelLow[TITAN_ZONELEVEL_ULDA]=35;
    zLevelHigh[TITAN_ZONELEVEL_ULDU]=49;
    zLevelLow[TITAN_ZONELEVEL_ULDU]=48;
    zLevelHigh[TITAN_ZONELEVEL_UNGOCR]=61;
    zLevelLow[TITAN_ZONELEVEL_UNGOCR]=48;
    zLevelHigh[TITAN_ZONELEVEL_URS]=52;
    zLevelLow[TITAN_ZONELEVEL_URS]=50;
--<< V >>--
    zLevelHigh[TITAN_ZONELEVEL_VAFI]=14;
    zLevelLow[TITAN_ZONELEVEL_VAFI]=10;
    zLevelHigh[TITAN_ZONELEVEL_VABO]=40;
    zLevelLow[TITAN_ZONELEVEL_VABO]=37;
    zLevelHigh[TITAN_ZONELEVEL_VAFA]=42;
    zLevelLow[TITAN_ZONELEVEL_VAFA]=35;
    zLevelHigh[TITAN_ZONELEVEL_VAHE]=0;
    zLevelLow[TITAN_ZONELEVEL_VAHE]=0;
    zLevelHigh[TITAN_ZONELEVEL_VAKI]=12;
    zLevelLow[TITAN_ZONELEVEL_VAKI]=11;
    zLevelHigh[TITAN_ZONELEVEL_VASP]=42;
    zLevelLow[TITAN_ZONELEVEL_VASP]=37;
    zLevelHigh[TITAN_ZONELEVEL_VABL]=0;
    zLevelLow[TITAN_ZONELEVEL_VABL]=0;
    zLevelHigh[TITAN_ZONELEVEL_VAWA]=49;
    zLevelLow[TITAN_ZONELEVEL_VAWA]=43;
    zLevelHigh[TITAN_ZONELEVEL_VATR]=35;
    zLevelLow[TITAN_ZONELEVEL_VATR]=1;
    zLevelHigh[TITAN_ZONELEVEL_VAL]=55;
    zLevelLow[TITAN_ZONELEVEL_VAL]=45;
    zLevelHigh[TITAN_ZONELEVEL_VALA]=47;
    zLevelLow[TITAN_ZONELEVEL_VALA]=43;
    zLevelHigh[TITAN_ZONELEVEL_VAEN]=0;
    zLevelLow[TITAN_ZONELEVEL_VAEN]=0;
    zLevelHigh[TITAN_ZONELEVEL_VEVA]=30;
    zLevelLow[TITAN_ZONELEVEL_VEVA]=8;
    zLevelHigh[TITAN_ZONELEVEL_VEBACA]=42;
    zLevelLow[TITAN_ZONELEVEL_VEBACA]=31;
    zLevelHigh[TITAN_ZONELEVEL_VEOPCE]=38;
    zLevelLow[TITAN_ZONELEVEL_VEOPCE]=31;
    zLevelHigh[TITAN_ZONELEVEL_VERI]=46;
    zLevelLow[TITAN_ZONELEVEL_VERI]=42;
    zLevelHigh[TITAN_ZONELEVEL_VUOGMO]=30;
    zLevelLow[TITAN_ZONELEVEL_VUOGMO]=27;
--<< W >>--
    zLevelHigh[TITAN_ZONELEVEL_WACA]=16;
    zLevelLow[TITAN_ZONELEVEL_WACA]=12;
    zLevelHigh[TITAN_ZONELEVEL_WALUCA]=29;
    zLevelLow[TITAN_ZONELEVEL_WALUCA]=25;
    zLevelHigh[TITAN_ZONELEVEL_WAFI]=46;
    zLevelLow[TITAN_ZONELEVEL_WAFI]=40;
    zLevelHigh[TITAN_ZONELEVEL_WABE]=45;
    zLevelLow[TITAN_ZONELEVEL_WABE]=40;
    zLevelHigh[TITAN_ZONELEVEL_WEPA]=30;
    zLevelLow[TITAN_ZONELEVEL_WEPA]=15;
    zLevelHigh[TITAN_ZONELEVEL_WEPI]=0;
    zLevelLow[TITAN_ZONELEVEL_WEPI]=0;
    zLevelHigh[TITAN_ZONELEVEL_WEGA]=9;
    zLevelLow[TITAN_ZONELEVEL_WEGA]=5;
    zLevelHigh[TITAN_ZONELEVEL_WEPL]=63;
    zLevelLow[TITAN_ZONELEVEL_WEPL]=50;
    zLevelHigh[TITAN_ZONELEVEL_WEST]=32;
    zLevelLow[TITAN_ZONELEVEL_WEST]=24;
    zLevelHigh[TITAN_ZONELEVEL_WELI]=0;
    zLevelLow[TITAN_ZONELEVEL_WELI]=0;
    zLevelHigh[TITAN_ZONELEVEL_WES]=19;
    zLevelLow[TITAN_ZONELEVEL_WES]=9;
    zLevelHigh[TITAN_ZONELEVEL_WET ]=27;
    zLevelLow[TITAN_ZONELEVEL_WET ]=20;
    zLevelHigh[TITAN_ZONELEVEL_WHEXSI]=29;
    zLevelLow[TITAN_ZONELEVEL_WHEXSI]=22;
    zLevelHigh[TITAN_ZONELEVEL_WHGA]=30;
    zLevelLow[TITAN_ZONELEVEL_WHGA]=10;
    zLevelHigh[TITAN_ZONELEVEL_WHSH]=0;
    zLevelLow[TITAN_ZONELEVEL_WHSH]=0;
    zLevelHigh[TITAN_ZONELEVEL_WHPO]=42;
    zLevelLow[TITAN_ZONELEVEL_WHPO]=24;
    zLevelHigh[TITAN_ZONELEVEL_WISH]=52;
    zLevelLow[TITAN_ZONELEVEL_WISH]=40;
    zLevelHigh[TITAN_ZONELEVEL_WILRI]=14;
    zLevelLow[TITAN_ZONELEVEL_WILRI]=13;
    zLevelHigh[TITAN_ZONELEVEL_WIKE]=45;
    zLevelLow[TITAN_ZONELEVEL_WIKE]=45;
    zLevelHigh[TITAN_ZONELEVEL_WILWAWE]=10;
    zLevelLow[TITAN_ZONELEVEL_WILWAWE]=8;
    zLevelHigh[TITAN_ZONELEVEL_WILA]=46;
    zLevelLow[TITAN_ZONELEVEL_WILA]=43;
    zLevelHigh[TITAN_ZONELEVEL_WICA]=29;
    zLevelLow[TITAN_ZONELEVEL_WICA]=27;
    zLevelHigh[TITAN_ZONELEVEL_WINRI]=11;
    zLevelLow[TITAN_ZONELEVEL_WINRI]=8;
    zLevelHigh[TITAN_ZONELEVEL_WICR]=23;
    zLevelLow[TITAN_ZONELEVEL_WICR]=14;
    zLevelHigh[TITAN_ZONELEVEL_WIMI]=22;
    zLevelLow[TITAN_ZONELEVEL_WIMI]=20;
    zLevelHigh[TITAN_ZONELEVEL_WINVI]=59;
    zLevelLow[TITAN_ZONELEVEL_WINVI]=55;
    zLevelHigh[TITAN_ZONELEVEL_WINWAWE]=8;
    zLevelLow[TITAN_ZONELEVEL_WINWAWE]=5;
    zLevelHigh[TITAN_ZONELEVEL_WIN]=60;
    zLevelLow[TITAN_ZONELEVEL_WIN]=53;
    zLevelHigh[TITAN_ZONELEVEL_WIHI]=38;
    zLevelLow[TITAN_ZONELEVEL_WIHI]=35;
    zLevelHigh[TITAN_ZONELEVEL_WITVI]=37;
    zLevelLow[TITAN_ZONELEVEL_WITVI]=31;
    zLevelHigh[TITAN_ZONELEVEL_WOHI]=46;
    zLevelLow[TITAN_ZONELEVEL_WOHI]=40;
    zLevelHigh[TITAN_ZONELEVEL_WOO]=44;
    zLevelLow[TITAN_ZONELEVEL_WOO]=42;
--<< X >>--
    zLevelHigh[TITAN_ZONELEVEL_XAV]=30;
    zLevelLow[TITAN_ZONELEVEL_XAV]=25;
--<< Z >>--
    zLevelHigh[TITAN_ZONELEVEL_ZADE]=0;
    zLevelLow[TITAN_ZONELEVEL_ZADE]=0;
    zLevelHigh[TITAN_ZONELEVEL_ZIRU]=40;
    zLevelLow[TITAN_ZONELEVEL_ZIRU]=37;
    zLevelHigh[TITAN_ZONELEVEL_ZOOU]=35;
    zLevelLow[TITAN_ZONELEVEL_ZOOU]=18;
    zLevelHigh[TITAN_ZONELEVEL_ZUGU]=0;
    zLevelLow[TITAN_ZONELEVEL_ZUGU]=0;
    zLevelHigh[TITAN_ZONELEVEL_ZUFA]=48;
    zLevelLow[TITAN_ZONELEVEL_ZUFA]=30;
    zLevelHigh[TITAN_ZONELEVEL_ZUMA]=59;
    zLevelLow[TITAN_ZONELEVEL_ZUMA]=57;
    zLevelHigh[TITAN_ZONELEVEL_ZUWA]=42;
    zLevelLow[TITAN_ZONELEVEL_ZUWA]=40;
    zLevelHigh[TITAN_ZONELEVEL_AURU]=38;
    zLevelLow[TITAN_ZONELEVEL_AURU]=35;
--<< Loading >>--
    zLevelHigh[TITAN_ZONELEVEL_LOAD]=0;
    zLevelLow[TITAN_ZONELEVEL_LOAD]=0;

end